"""
Full FFI bindings to the MicroPDF Rust library.

This module contains the complete C API definitions for all 2492 functions
from the MicroPDF Rust library, enabling comprehensive PDF manipulation.

Coverage: 100% of FFI functions
"""

FULL_FFI_DEFS = """
    // ============================================================================
    // CBZ (COMIC BOOK) FUNCTIONS (35 functions)
    // ============================================================================

char* cbz_format_name(uint64_t, int32_t);
char* cbz_get_number(uint64_t, uint64_t);
char* cbz_get_page_filename(uint64_t, uint64_t, int32_t);
char* cbz_get_publisher(uint64_t, uint64_t);
char* cbz_get_series(uint64_t, uint64_t);
char* cbz_get_summary(uint64_t, uint64_t);
char* cbz_get_title(uint64_t, uint64_t);
char* cbz_get_writer(uint64_t, uint64_t);
char* cbz_image_format_name(uint64_t, int32_t);
int32_t cbz_add_entry(uint64_t, uint64_t, const char*);
int32_t cbz_get_format(uint64_t, uint64_t);
int32_t cbz_get_manga(uint64_t, uint64_t);
int32_t cbz_get_page_format(uint64_t, uint64_t, int32_t);
int32_t cbz_get_page_size(uint64_t, uint64_t, int32_t, int*, int*);
int32_t cbz_get_year(uint64_t, uint64_t);
int32_t cbz_is_image_file(uint64_t, const char*);
int32_t cbz_page_count(uint64_t, uint64_t);
int32_t cbz_page_is_double(uint64_t, uint64_t, int32_t);
int32_t cbz_set_manga(uint64_t, uint64_t, int32_t);
int32_t cbz_set_number(uint64_t, uint64_t, const char*);
int32_t cbz_set_page_double(uint64_t, uint64_t, int32_t, int32_t);
int32_t cbz_set_page_size(uint64_t, uint64_t, int32_t, int32_t, int32_t);
int32_t cbz_set_publisher(uint64_t, uint64_t, const char*);
int32_t cbz_set_series(uint64_t, uint64_t, const char*);
int32_t cbz_set_summary(uint64_t, uint64_t, const char*);
int32_t cbz_set_title(uint64_t, uint64_t, const char*);
int32_t cbz_set_writer(uint64_t, uint64_t, const char*);
int32_t cbz_set_year(uint64_t, uint64_t, int32_t);
int32_t cbz_sort_pages(uint64_t, uint64_t);
uint64_t cbz_new_document(uint64_t);
uint64_t cbz_open_document(uint64_t, const char*);
uint64_t cbz_open_document_with_archive(uint64_t, uint64_t);
uint64_t cbz_open_document_with_stream(uint64_t, uint64_t);
void cbz_drop_document(uint64_t, uint64_t);
void cbz_free_string(char*);

    // ============================================================================
    // EPUB FUNCTIONS (35 functions)
    // ============================================================================

char* epub_get_creator(uint64_t, uint64_t, int32_t);
char* epub_get_identifier(uint64_t, uint64_t);
char* epub_get_language(uint64_t, uint64_t);
char* epub_get_manifest_href(uint64_t, uint64_t, const char*);
char* epub_get_spine_idref(uint64_t, uint64_t, int32_t);
char* epub_get_title(uint64_t, uint64_t);
char* epub_get_toc_content(uint64_t, uint64_t, int32_t);
char* epub_get_toc_label(uint64_t, uint64_t, int32_t);
char* epub_media_type_string(uint64_t, int32_t);
const unsigned char* epub_get_file_data(uint64_t, uint64_t, const char*, size_t*);
int32_t epub_add_creator(uint64_t, uint64_t, const char*);
int32_t epub_add_file(uint64_t, uint64_t, const char*, const unsigned char*, size_t);
int32_t epub_add_manifest_item(uint64_t, uint64_t, const char*, const char*, const char*);
int32_t epub_add_spine_item(uint64_t, uint64_t, const char*, int32_t);
int32_t epub_add_toc_entry(uint64_t, uint64_t, const char*, const char*, const char*);
int32_t epub_get_creator_count(uint64_t, uint64_t);
int32_t epub_get_direction(uint64_t, uint64_t);
int32_t epub_get_manifest_media_type(uint64_t, uint64_t, const char*);
int32_t epub_get_version(uint64_t, uint64_t);
int32_t epub_has_file(uint64_t, uint64_t, const char*);
int32_t epub_manifest_count(uint64_t, uint64_t);
int32_t epub_set_direction(uint64_t, uint64_t, int32_t);
int32_t epub_set_identifier(uint64_t, uint64_t, const char*);
int32_t epub_set_language(uint64_t, uint64_t, const char*);
int32_t epub_set_title(uint64_t, uint64_t, const char*);
int32_t epub_set_version(uint64_t, uint64_t, int32_t);
int32_t epub_spine_count(uint64_t, uint64_t);
int32_t epub_spine_item_is_linear(uint64_t, uint64_t, int32_t);
int32_t epub_toc_count(uint64_t, uint64_t);
uint64_t epub_new_document(uint64_t);
uint64_t epub_open_document(uint64_t, const char*);
uint64_t epub_open_document_with_archive(uint64_t, uint64_t);
uint64_t epub_open_document_with_stream(uint64_t, uint64_t);
void epub_drop_document(uint64_t, uint64_t);
void epub_free_string(char*);

    // ============================================================================
    // CORE FITZ FUNCTIONS (1416 functions)
    // ============================================================================

char* fz_cleanname(char*);
char* fz_decode_barcode_from_pixmap(uint64_t, int*, uint64_t, int32_t);
char* fz_decode_uri(uint64_t, const char*);
char* fz_decode_uri_component(uint64_t, const char*);
char* fz_encode_uri(uint64_t, const char*);
char* fz_encode_uri_component(uint64_t, const char*);
char* fz_encode_uri_pathname(uint64_t, const char*);
char* fz_make_location_uri(uint64_t, uint64_t, int32_t, char*, int32_t);
char* fz_ocr_engine_get_language(uint64_t, uint64_t);
char* fz_ocr_result_text(uint64_t, uint64_t);
char* fz_read_line(uint64_t, uint64_t, char*, size_t);
char* fz_strdup(uint64_t, const char*);
char* fz_strsep(char*, const char*);
char* fz_table_get_cell_text(uint64_t, uint64_t, uint64_t, uint64_t);
char* fz_table_to_csv(uint64_t, uint64_t);
char* fz_table_to_html(uint64_t, uint64_t);
char* fz_table_to_markdown(uint64_t, uint64_t);
char* fz_urldecode(char*);
char* fz_validation_issue_code(uint64_t, uint64_t, uint64_t);
char* fz_validation_issue_message(uint64_t, uint64_t, uint64_t);
const char* fz_basename(const char*);
const char* fz_caught_message(uint64_t);
const char* fz_colorspace_colorant(uint64_t, uint64_t, int32_t);
const char* fz_colorspace_name(uint64_t, uint64_t);
const char* fz_colorspace_name_string(uint64_t, uint64_t);
const char* fz_convert_error(uint64_t, void*);
const char* fz_copy_rectangle(uint64_t, uint64_t, float, float, float, float, int32_t);
const char* fz_copy_selection(uint64_t, uint64_t, float, float, float, float, int32_t);
const char* fz_log_last_warning(uint64_t);
const char* fz_log_level_name(int32_t);
const char* fz_outline_title(uint64_t, uint64_t);
const char* fz_outline_uri(uint64_t, uint64_t);
const char* fz_pdfa_level_name(uint64_t);
const char* fz_pdfx_level_name(uint64_t);
const char* fz_print_stext_page_as_html(uint64_t, uint64_t, uint64_t, int32_t);
const char* fz_print_stext_page_as_json(uint64_t, uint64_t, uint64_t, float);
const char* fz_print_stext_page_as_xml(uint64_t, uint64_t, uint64_t, int32_t);
const char* fz_rendering_intent_name(int32_t);
const char* fz_runeptr(const char*, int32_t);
const char* fz_separation_name(uint64_t, uint64_t, int32_t);
const char* fz_standard_name_str(uint64_t);
const char* fz_stext_page_as_text(uint64_t, uint64_t);
const char* fz_story_warnings(uint64_t, uint64_t);
const char* fz_string_from_barcode_type(int32_t);
const char* fz_string_from_box_type(int32_t);
const char* fz_string_from_buffer(uint64_t, uint64_t);
const char* fz_strstr(const char*, const char*);
const char* fz_strstrcase(const char*, const char*);
const char* fz_text_language_code(int32_t);
const char* fz_tree_node_actual_text(uint64_t, uint64_t);
const char* fz_tree_node_alt(uint64_t, uint64_t);
const char* fz_tree_node_lang(uint64_t, uint64_t);
const char* fz_tree_node_title(uint64_t, uint64_t);
const char* fz_tree_node_type_name(uint64_t, uint64_t);
const char* fz_xml_att(uint64_t, uint64_t, const char*);
const char* fz_xml_tag(uint64_t, uint64_t);
const char* fz_xml_text(uint64_t, uint64_t);
const unsigned char* fz_band_writer_get_output(uint64_t, uint64_t, size_t*);
const unsigned char* fz_bitmap_data(uint64_t, uint64_t);
const unsigned char* fz_buffer_data(uint64_t, uint64_t, size_t*);
const unsigned char* fz_colorspace_lookup(uint64_t, uint64_t);
const unsigned char* fz_filter_data(uint64_t, uint64_t);
const void* fz_memmem(const void*, size_t, const void*, size_t);
const void* fz_outline_iterator_item(uint64_t, uint64_t);
double fz_detect_skew(uint64_t, uint64_t);
double fz_json_to_number(uint64_t, uint64_t);
float fz_advance_glyph(uint64_t, uint64_t, int32_t, int32_t);
float fz_atof(const char*);
float fz_band_writer_progress(uint64_t, uint64_t);
float fz_clamp_f32(float, float, float);
float fz_colorspace_max(uint64_t, uint64_t);
float fz_cookie_progress_float(uint64_t, uint64_t);
float fz_font_ascender(uint64_t, uint64_t);
float fz_font_descender(uint64_t, uint64_t);
float fz_glyph_advance(uint64_t, uint64_t, int32_t);
float fz_glyph_cache_hit_rate(uint64_t);
float fz_glyph_cache_utilization(uint64_t);
float fz_glyph_variation(uint64_t, uint64_t, int32_t);
float fz_max_f32(float, float);
float fz_min_f32(float, float);
float fz_outline_color_b(uint64_t, uint64_t);
float fz_outline_color_g(uint64_t, uint64_t);
float fz_outline_color_r(uint64_t, uint64_t);
float fz_outline_x(uint64_t, uint64_t);
float fz_outline_y(uint64_t, uint64_t);
float fz_pool_fragmentation(uint64_t, uint64_t);
float fz_read_float(uint64_t, uint64_t);
float fz_read_float_le(uint64_t, uint64_t);
float fz_stext_char_size(uint64_t, uint64_t, int32_t, int32_t, int32_t);
float fz_store_hit_rate(uint64_t);
float fz_story_em(uint64_t);
float fz_stroke_state_dash_phase(uint64_t, uint64_t);
float fz_stroke_state_linewidth(uint64_t, uint64_t);
float fz_stroke_state_miterlimit(uint64_t, uint64_t);
float fz_strtof(const char*, char*);
float fz_table_confidence(uint64_t, uint64_t);
float fz_tile_renderer_progress(uint64_t, uint64_t);
float fz_transition_duration(uint64_t);
fz_irect fz_expand_irect(fz_irect, int32_t);
fz_irect fz_intersect_irect(fz_irect, fz_irect);
fz_irect fz_irect_from_rect(fz_rect);
fz_irect fz_make_irect(int32_t, int32_t, int32_t, int32_t);
fz_irect fz_pixmap_bbox(uint64_t, uint64_t);
fz_irect fz_round_rect(fz_rect);
fz_irect fz_translate_irect(fz_irect, int32_t, int32_t);
fz_matrix fz_concat(fz_matrix, fz_matrix);
fz_matrix fz_invert_matrix(fz_matrix);
fz_matrix fz_post_rotate(fz_matrix, uint64_t);
fz_matrix fz_post_scale(fz_matrix, uint64_t, uint64_t);
fz_matrix fz_post_translate(fz_matrix, uint64_t, uint64_t);
fz_matrix fz_pre_rotate(fz_matrix, uint64_t);
fz_matrix fz_pre_scale(fz_matrix, uint64_t, uint64_t);
fz_matrix fz_pre_shear(fz_matrix, uint64_t, uint64_t);
fz_matrix fz_pre_translate(fz_matrix, uint64_t, uint64_t);
fz_matrix fz_rotate(uint64_t);
fz_matrix fz_scale(uint64_t, uint64_t);
fz_matrix fz_shear(uint64_t, uint64_t);
fz_matrix fz_translate(uint64_t, uint64_t);
fz_point fz_currentpoint(uint64_t, uint64_t);
fz_point fz_make_point(uint64_t, uint64_t);
fz_point fz_normalize_vector(fz_point);
fz_point fz_rect_center(fz_rect);
fz_point fz_transform_point(fz_point, fz_matrix);
fz_point fz_transform_point_xy(uint64_t, uint64_t, fz_matrix);
fz_point fz_transform_vector(fz_point, fz_matrix);
fz_quad fz_quad_from_rect(fz_rect);
fz_quad fz_transform_quad(fz_quad, fz_matrix);
fz_rect fz_bound_display_list(uint64_t, uint64_t);
fz_rect fz_bound_glyph(uint64_t, uint64_t, int32_t, fz_matrix);
fz_rect fz_bound_page(uint64_t, uint64_t);
fz_rect fz_bound_page_box(uint64_t, uint64_t, int32_t);
fz_rect fz_bound_path(uint64_t, uint64_t, uint64_t, fz_matrix);
fz_rect fz_bound_text(uint64_t, uint64_t, uint64_t, fz_matrix);
fz_rect fz_expand_rect(fz_rect, uint64_t);
fz_rect fz_font_bbox(uint64_t, uint64_t);
fz_rect fz_include_point_in_rect(fz_rect, fz_point);
fz_rect fz_intersect_rect(fz_rect, fz_rect);
fz_rect fz_link_rect(uint64_t, uint64_t);
fz_rect fz_make_rect(uint64_t, uint64_t, uint64_t, uint64_t);
fz_rect fz_rect_from_irect(fz_irect);
fz_rect fz_rect_from_quad(fz_quad);
fz_rect fz_transform_rect(fz_rect, fz_matrix);
fz_rect fz_translate_rect(fz_rect, uint64_t, uint64_t);
fz_rect fz_union_rect(fz_rect, fz_rect);
int16_t fz_read_int16(uint64_t, uint64_t);
int16_t fz_read_int16_le(uint64_t, uint64_t);
int32_t fz_add_separation(uint64_t, uint64_t, const char*, uint64_t, float, float, float, float);
int32_t fz_add_separation_all(uint64_t, uint64_t);
int32_t fz_add_separation_none(uint64_t, uint64_t);
int32_t fz_add_stext_block(uint64_t, uint64_t, float, float, float, float);
int32_t fz_add_stext_char(uint64_t, uint64_t, int32_t, int32_t, int32_t, float, float, float);
int32_t fz_add_stext_line(uint64_t, uint64_t, int32_t, float, float, float, float);
int32_t fz_archive_entry_names(uint64_t, uint64_t, char*, int32_t);
int32_t fz_archive_entry_size(uint64_t, uint64_t, const char*);
int32_t fz_archive_format(uint64_t, uint64_t);
int32_t fz_archive_is_valid(uint64_t, uint64_t);
int32_t fz_atoi(const char*);
int32_t fz_authenticate_password(uint64_t, uint64_t, const char*);
int32_t fz_band_writer_current_band(uint64_t, uint64_t);
int32_t fz_band_writer_state(uint64_t, uint64_t);
int32_t fz_band_writer_total_bands(uint64_t, uint64_t);
int32_t fz_band_writer_write_band(uint64_t, uint64_t, int32_t, const unsigned char*);
int32_t fz_band_writer_write_header(uint64_t, uint64_t);
int32_t fz_band_writer_write_trailer(uint64_t, uint64_t);
int32_t fz_barcode_check_digit(int32_t, const char*);
int32_t fz_barcode_default_size(int32_t);
int32_t fz_barcode_is_1d(int32_t);
int32_t fz_barcode_is_2d(int32_t);
int32_t fz_barcode_type_count(void);
int32_t fz_barcode_type_from_string(const char*);
int32_t fz_barcode_validate(int32_t, const char*);
int32_t fz_begin_tile(uint64_t, uint64_t, fz_rect, fz_rect, float, float, fz_matrix);
int32_t fz_bidi_char_type(uint32_t);
int32_t fz_bidi_detect_direction(uint64_t, const uint32_t*, size_t);
int32_t fz_bidi_direction_from_char(uint32_t);
int32_t fz_bidi_get_level(uint64_t, const uint32_t*, size_t, int32_t, size_t);
int32_t fz_bidi_has_mirror(uint32_t);
int32_t fz_bidi_has_rtl(uint64_t, const uint32_t*, size_t);
int32_t fz_bidi_is_control(uint32_t);
int32_t fz_bidi_is_ltr_only(uint64_t, const uint32_t*, size_t);
int32_t fz_bidi_is_rtl_only(uint64_t, const uint32_t*, size_t);
int32_t fz_bitmap_get_pixel(uint64_t, uint64_t, int32_t, int32_t);
int32_t fz_bitmap_height(uint64_t, uint64_t);
int32_t fz_bitmap_stride(uint64_t, uint64_t);
int32_t fz_bitmap_width(uint64_t, uint64_t);
int32_t fz_bitmap_x_res(uint64_t, uint64_t);
int32_t fz_bitmap_y_res(uint64_t, uint64_t);
int32_t fz_box_type_from_string(const char*);
int32_t fz_buffer_eq(uint64_t, uint64_t, uint64_t);
int32_t fz_byte_to_char_offset(uint64_t, const char*, size_t);
int32_t fz_char_to_byte_offset(uint64_t, const char*, size_t);
int32_t fz_chartorune(int*, const char*);
int32_t fz_chartorunen(int*, const char*, size_t);
int32_t fz_clamp_i32(int32_t, int32_t, int32_t);
int32_t fz_color_params_bp(uint64_t);
int32_t fz_color_params_op(uint64_t);
int32_t fz_color_params_opm(uint64_t);
int32_t fz_color_params_ri(uint64_t);
int32_t fz_colorspace_base_n(uint64_t, uint64_t);
int32_t fz_colorspace_device_n_has_cmyk(uint64_t, uint64_t);
int32_t fz_colorspace_device_n_has_only_cmyk(uint64_t, uint64_t);
int32_t fz_colorspace_eq(uint64_t, uint64_t, uint64_t);
int32_t fz_colorspace_has_spots(uint64_t, uint64_t);
int32_t fz_colorspace_high(uint64_t, uint64_t);
int32_t fz_colorspace_is_cmyk(uint64_t, uint64_t);
int32_t fz_colorspace_is_device(uint64_t, uint64_t);
int32_t fz_colorspace_is_device_n(uint64_t, uint64_t);
int32_t fz_colorspace_is_gray(uint64_t, uint64_t);
int32_t fz_colorspace_is_icc(uint64_t, uint64_t);
int32_t fz_colorspace_is_indexed(uint64_t, uint64_t);
int32_t fz_colorspace_is_lab(uint64_t, uint64_t);
int32_t fz_colorspace_is_rgb(uint64_t, uint64_t);
int32_t fz_colorspace_is_subtractive(uint64_t, uint64_t);
int32_t fz_colorspace_is_valid(uint64_t, uint64_t);
int32_t fz_colorspace_n(uint64_t, uint64_t);
int32_t fz_colorspace_n_spots(uint64_t, uint64_t);
int32_t fz_colorspace_num_colorants(uint64_t, uint64_t);
int32_t fz_colorspace_type(uint64_t, uint64_t);
int32_t fz_compressed_buffer_get_type(uint64_t, uint64_t);
int32_t fz_contains_rect(fz_rect, fz_rect);
int32_t fz_cookie_get_errors(uint64_t, uint64_t);
int32_t fz_cookie_get_progress(uint64_t, uint64_t);
int32_t fz_cookie_get_progress_max(uint64_t, uint64_t);
int32_t fz_cookie_has_errors(uint64_t, uint64_t);
int32_t fz_cookie_is_aborted(uint64_t, uint64_t);
int32_t fz_cookie_is_complete(uint64_t, uint64_t);
int32_t fz_cookie_is_incomplete(uint64_t, uint64_t);
int32_t fz_cookie_is_valid(uint64_t, uint64_t);
int32_t fz_cookie_progress(uint64_t, uint64_t);
int32_t fz_cookie_progress_percent(uint64_t, uint64_t);
int32_t fz_cookie_progress_remaining(uint64_t, uint64_t);
int32_t fz_cookie_should_abort(uint64_t, uint64_t);
int32_t fz_count_active_separations(uint64_t, uint64_t);
int32_t fz_count_archive_entries(uint64_t, uint64_t);
int32_t fz_count_chapter_pages(uint64_t, uint64_t, int32_t);
int32_t fz_count_chapters(uint64_t, uint64_t);
int32_t fz_count_pages(uint64_t, uint64_t);
int32_t fz_count_separations(uint64_t, uint64_t);
int32_t fz_decompress_brotli(uint64_t, unsigned char*, size_t*, const unsigned char*, size_t);
int32_t fz_detect_script(uint64_t, const char*);
int32_t fz_detect_skew_angle(uint64_t, uint64_t, double*);
int32_t fz_device_is_valid(uint64_t, uint64_t);
int32_t fz_display_list_count_commands(uint64_t, uint64_t);
int32_t fz_display_list_is_empty(uint64_t, uint64_t);
int32_t fz_display_list_is_valid(uint64_t, uint64_t);
int32_t fz_document_format(uint64_t, uint64_t, char*, int32_t);
int32_t fz_document_is_valid(uint64_t, uint64_t);
int32_t fz_document_writer_format(uint64_t);
int32_t fz_document_writer_is_closed(uint64_t);
int32_t fz_document_writer_page_count(uint64_t);
int32_t fz_draw_device_clip_depth(uint64_t, uint64_t);
int32_t fz_draw_device_draw_glyph(uint64_t, uint64_t, uint64_t, uint32_t, float, float, float);
int32_t fz_draw_device_fill(uint64_t, uint64_t, int32_t);
int32_t fz_draw_device_stroke(uint64_t, uint64_t);
int32_t fz_encode_character(uint64_t, uint64_t, int32_t);
int32_t fz_encode_character_with_fallback(uint64_t, uint64_t, int32_t, int32_t, int32_t, uint64_t);
int32_t fz_font_is_bold(uint64_t, uint64_t);
int32_t fz_font_is_embedded(uint64_t, uint64_t);
int32_t fz_font_is_italic(uint64_t, uint64_t);
int32_t fz_font_is_monospaced(uint64_t, uint64_t);
int32_t fz_font_is_serif(uint64_t, uint64_t);
int32_t fz_font_is_valid(uint64_t, uint64_t);
int32_t fz_generate_transition(uint64_t, uint64_t, uint64_t, uint64_t, int32_t, uint64_t);
int32_t fz_get_bidi_direction(uint64_t, const char*);
int32_t fz_get_log_level(uint64_t);
int32_t fz_get_module_log_level(uint64_t, const char*);
int32_t fz_get_word_at(uint64_t, const char*, size_t, size_t*, size_t*);
int32_t fz_glyph_add_color_layer(uint64_t, uint64_t, uint32_t, uint16_t);
int32_t fz_glyph_cache_policy(uint64_t);
int32_t fz_glyph_cache_size(uint64_t);
int32_t fz_glyph_color_layer(uint64_t, uint64_t, int32_t, uint32_t*, uint16_t*);
int32_t fz_glyph_color_layer_count(uint64_t, uint64_t);
int32_t fz_glyph_hinting(uint64_t, uint64_t);
int32_t fz_glyph_is_color(uint64_t, uint64_t);
int32_t fz_glyph_variation_count(uint64_t, uint64_t);
int32_t fz_gpu_backend_available(int32_t);
int32_t fz_gpu_clear_texture(uint64_t, uint64_t, float, float, float, float);
int32_t fz_gpu_composite(uint64_t, uint64_t, uint64_t, int32_t, int32_t, int32_t);
int32_t fz_gpu_device_backend(uint64_t);
int32_t fz_gpu_finish(uint64_t);
int32_t fz_gpu_flush(uint64_t);
int32_t fz_gpu_render_page(uint64_t, uint64_t, uint64_t, const float*);
int32_t fz_gpu_texture_height(uint64_t);
int32_t fz_gpu_texture_width(uint64_t);
int32_t fz_has_archive_entry(uint64_t, uint64_t, const char*);
int32_t fz_has_option(uint64_t, const char*, const char*, const char*);
int32_t fz_has_permission(uint64_t, uint64_t, int32_t);
int32_t fz_heap_is_empty(uint64_t, uint64_t);
int32_t fz_heap_type(uint64_t, uint64_t);
int32_t fz_highlight_selection(uint64_t, uint64_t, float, float, float, float, void*, int32_t);
int32_t fz_hyphenate_word(uint64_t, uint64_t, const char*, int32_t, char*, int32_t);
int32_t fz_hyphenator_add_pattern(uint64_t, uint64_t, const char*);
int32_t fz_hyphenator_language(uint64_t, uint64_t);
int32_t fz_hyphenator_load_patterns(uint64_t, uint64_t, const char*);
int32_t fz_image_bpp(uint64_t, uint64_t);
int32_t fz_image_h(uint64_t, uint64_t);
int32_t fz_image_has_alpha(uint64_t, uint64_t);
int32_t fz_image_height(uint64_t, uint64_t);
int32_t fz_image_is_mask(uint64_t, uint64_t);
int32_t fz_image_is_valid(uint64_t, uint64_t);
int32_t fz_image_orientation(uint64_t, uint64_t);
int32_t fz_image_w(uint64_t, uint64_t);
int32_t fz_image_width(uint64_t, uint64_t);
int32_t fz_image_xres(uint64_t, uint64_t);
int32_t fz_image_yres(uint64_t, uint64_t);
int32_t fz_inflate(uint64_t, unsigned char*, size_t*, const unsigned char*, size_t);
int32_t fz_int2_heap_insert(uint64_t, uint64_t, int32_t, int32_t);
int32_t fz_int2_heap_pop(uint64_t, uint64_t, int*, int*);
int32_t fz_int_heap_insert(uint64_t, uint64_t, int32_t);
int32_t fz_int_heap_peek(uint64_t, uint64_t, int*);
int32_t fz_int_heap_pop(uint64_t, uint64_t, int*);
int32_t fz_intptr_heap_insert(uint64_t, uint64_t, int32_t, size_t);
int32_t fz_intptr_heap_pop(uint64_t, uint64_t, int*, size_t*);
int32_t fz_irect_area(fz_irect);
int32_t fz_irect_eq(fz_irect, fz_irect);
int32_t fz_irect_height(fz_irect);
int32_t fz_irect_width(fz_irect);
int32_t fz_is_document_reflowable(uint64_t, uint64_t);
int32_t fz_is_empty_irect(fz_irect);
int32_t fz_is_empty_rect(fz_rect);
int32_t fz_is_eof(uint64_t, uint64_t);
int32_t fz_is_external_link(uint64_t, uint64_t);
int32_t fz_is_infinite_irect(fz_irect);
int32_t fz_is_infinite_rect(fz_rect);
int32_t fz_is_page_link(uint64_t, uint64_t);
int32_t fz_is_page_range(uint64_t, const char*);
int32_t fz_is_point_inside_irect(int32_t, int32_t, fz_irect);
int32_t fz_is_point_inside_rect(fz_point, fz_rect);
int32_t fz_is_rectilinear(fz_matrix);
int32_t fz_is_skewed(uint64_t, uint64_t, double);
int32_t fz_is_unicode_hyphen(uint32_t);
int32_t fz_is_valid_blend_colorspace(uint64_t, uint64_t);
int32_t fz_json_array_length(uint64_t, uint64_t);
int32_t fz_json_array_push(uint64_t, uint64_t, uint64_t, uint64_t);
int32_t fz_json_is_array(uint64_t, uint64_t);
int32_t fz_json_is_boolean(uint64_t, uint64_t);
int32_t fz_json_is_null(uint64_t, uint64_t);
int32_t fz_json_is_number(uint64_t, uint64_t);
int32_t fz_json_is_object(uint64_t, uint64_t);
int32_t fz_json_is_string(uint64_t, uint64_t);
int32_t fz_json_object_length(uint64_t, uint64_t);
int32_t fz_json_object_set(uint64_t, uint64_t, uint64_t, const char*, uint64_t);
int32_t fz_json_to_boolean(uint64_t, uint64_t);
int32_t fz_json_type(uint64_t, uint64_t);
int32_t fz_link_eq(uint64_t, uint64_t, uint64_t);
int32_t fz_link_is_valid(uint64_t, uint64_t);
int32_t fz_link_list_count(uint64_t, uint64_t);
int32_t fz_link_list_is_empty(uint64_t, uint64_t);
int32_t fz_link_page_number(uint64_t, uint64_t);
int32_t fz_link_uri(uint64_t, uint64_t, char*, int32_t);
int32_t fz_list_archive_entry(uint64_t, uint64_t, int32_t, char*, int32_t);
int32_t fz_lookup_image_type(uint64_t);
int32_t fz_lookup_metadata(uint64_t, uint64_t, const char*, char*, int32_t);
int32_t fz_lookup_rendering_intent(const char*);
int32_t fz_matrix_is_singular(fz_matrix);
int32_t fz_max_colors(void);
int32_t fz_max_i32(int32_t, int32_t);
int32_t fz_min_i32(int32_t, int32_t);
int32_t fz_needs_password(uint64_t, uint64_t);
int32_t fz_new_store(uint64_t, size_t);
int32_t fz_option_eq(const char*, const char*);
int32_t fz_outline_count(uint64_t, uint64_t);
int32_t fz_outline_depth(uint64_t, uint64_t);
int32_t fz_outline_flags(uint64_t, uint64_t);
int32_t fz_outline_is_open(uint64_t, uint64_t);
int32_t fz_outline_iterator_delete(uint64_t, uint64_t);
int32_t fz_outline_iterator_down(uint64_t, uint64_t);
int32_t fz_outline_iterator_insert(uint64_t, uint64_t, const void*);
int32_t fz_outline_iterator_next(uint64_t, uint64_t);
int32_t fz_outline_iterator_prev(uint64_t, uint64_t);
int32_t fz_outline_iterator_up(uint64_t, uint64_t);
int32_t fz_outline_page(uint64_t, uint64_t);
int32_t fz_overlaps_rect(fz_rect, fz_rect);
int32_t fz_page_label(uint64_t, uint64_t, int32_t, char*, int32_t);
int32_t fz_page_number_from_location(uint64_t, uint64_t, int32_t, int32_t);
int32_t fz_parse_log_level(const char*);
int32_t fz_path_is_valid(uint64_t, uint64_t);
int32_t fz_peek_byte(uint64_t, uint64_t);
int32_t fz_pixmap_alpha(uint64_t, uint64_t);
int32_t fz_pixmap_colorants(uint64_t, uint64_t);
int32_t fz_pixmap_components(uint64_t, uint64_t);
int32_t fz_pixmap_height(uint64_t, uint64_t);
int32_t fz_pixmap_is_valid(uint64_t, uint64_t);
int32_t fz_pixmap_stride(uint64_t, uint64_t);
int32_t fz_pixmap_width(uint64_t, uint64_t);
int32_t fz_pixmap_x(uint64_t, uint64_t);
int32_t fz_pixmap_xres(uint64_t, uint64_t);
int32_t fz_pixmap_y(uint64_t, uint64_t);
int32_t fz_pixmap_yres(uint64_t, uint64_t);
int32_t fz_place_story(uint64_t, uint64_t, float, float, float, float, void*);
int32_t fz_place_story_flags(uint64_t, uint64_t, float, float, float, float, void*, int32_t);
int32_t fz_ptr_heap_insert(uint64_t, uint64_t, size_t);
int32_t fz_ptr_heap_pop(uint64_t, uint64_t, size_t*);
int32_t fz_read_byte(uint64_t, uint64_t);
int32_t fz_read_int32(uint64_t, uint64_t);
int32_t fz_read_int32_le(uint64_t, uint64_t);
int32_t fz_recognize_image_format(uint64_t, const unsigned char*);
int32_t fz_rect_eq(fz_rect, fz_rect);
int32_t fz_rendered_glyph_cache_remove(uint64_t, uint64_t, int32_t, const void*, uint8_t, uint8_t, int32_t);
int32_t fz_resolve_link(uint64_t, uint64_t, const char*, float*, float*);
int32_t fz_runeidx(const char*, const char*);
int32_t fz_runelen(int32_t);
int32_t fz_runetochar(char*, int32_t);
int32_t fz_save_pixmap_as_jpeg(uint64_t, uint64_t, const char*, int32_t);
int32_t fz_save_pixmap_as_pam(uint64_t, uint64_t, const char*);
int32_t fz_save_pixmap_as_pbm(uint64_t, uint64_t, const char*);
int32_t fz_save_pixmap_as_pkm(uint64_t, uint64_t, const char*);
int32_t fz_save_pixmap_as_png(uint64_t, uint64_t, const char*);
int32_t fz_save_pixmap_as_pnm(uint64_t, uint64_t, const char*);
int32_t fz_save_pixmap_as_ps(uint64_t, uint64_t, const char*, int32_t);
int32_t fz_save_pixmap_as_psd(uint64_t, uint64_t, const char*);
int32_t fz_search_stext_page(uint64_t, uint64_t, const char*, int*, void*, int32_t);
int32_t fz_segment_stext_page(uint64_t, uint64_t);
int32_t fz_separation_current_behavior(uint64_t, uint64_t, int32_t);
int32_t fz_separation_is_all(uint64_t, uint64_t, int32_t);
int32_t fz_separation_is_none(uint64_t, uint64_t, int32_t);
int32_t fz_separations_controllable(uint64_t, uint64_t);
int32_t fz_separations_equal(uint64_t, uint64_t, uint64_t);
int32_t fz_separations_have_spots(uint64_t, uint64_t);
int32_t fz_set_link_uri(uint64_t, uint64_t, const char*);
int32_t fz_shade_add_color_stop(uint64_t, uint64_t, float, const float*, int32_t);
int32_t fz_shade_add_patch(uint64_t, uint64_t, const void*, const void*);
int32_t fz_shade_add_vertex(uint64_t, uint64_t, float, float, const float*, int32_t);
int32_t fz_shade_color_stop_count(uint64_t, uint64_t);
int32_t fz_shade_extend_end(uint64_t, uint64_t);
int32_t fz_shade_extend_start(uint64_t, uint64_t);
int32_t fz_shade_get_color_stop(uint64_t, uint64_t, int32_t, float*, float*);
int32_t fz_shade_has_background(uint64_t, uint64_t);
int32_t fz_shade_patch_count(uint64_t, uint64_t);
int32_t fz_shade_type(uint64_t, uint64_t);
int32_t fz_shade_vertex_count(uint64_t, uint64_t);
int32_t fz_stext_block_count(uint64_t, uint64_t);
int32_t fz_stext_block_type(uint64_t, uint64_t, int32_t);
int32_t fz_stext_char_count(uint64_t, uint64_t, int32_t, int32_t);
int32_t fz_stext_char_value(uint64_t, uint64_t, int32_t, int32_t, int32_t);
int32_t fz_stext_first_block(uint64_t, uint64_t);
int32_t fz_stext_first_char(uint64_t, uint64_t, int32_t, int32_t);
int32_t fz_stext_first_line(uint64_t, uint64_t, int32_t);
int32_t fz_stext_line_count(uint64_t, uint64_t, int32_t);
int32_t fz_stext_line_wmode(uint64_t, uint64_t, int32_t, int32_t);
int32_t fz_stext_next_block(uint64_t, uint64_t, int32_t);
int32_t fz_stext_next_char(uint64_t, uint64_t, int32_t, int32_t, int32_t);
int32_t fz_stext_next_line(uint64_t, uint64_t, int32_t, int32_t);
int32_t fz_store_item_type(uint64_t, uint64_t);
int32_t fz_story_is_complete(uint64_t);
int32_t fz_story_placed_regions_count(uint64_t);
int32_t fz_story_rectangle_num(uint64_t);
int32_t fz_story_state(uint64_t);
int32_t fz_strcasecmp(const char*, const char*);
int32_t fz_strcoll(uint64_t, const char*, const char*, const char*);
int32_t fz_string_is_normalized(uint64_t, const char*, int32_t);
int32_t fz_strncasecmp(const char*, const char*, size_t);
int32_t fz_stroke_state_dash_len(uint64_t, uint64_t);
int32_t fz_stroke_state_dash_pattern(uint64_t, uint64_t, float*, int32_t);
int32_t fz_stroke_state_end_cap(uint64_t, uint64_t);
int32_t fz_stroke_state_is_valid(uint64_t, uint64_t);
int32_t fz_stroke_state_linejoin(uint64_t, uint64_t);
int32_t fz_stroke_state_start_cap(uint64_t, uint64_t);
int32_t fz_strverscmp(const char*, const char*);
int32_t fz_text_count_items(uint64_t, uint64_t);
int32_t fz_text_count_spans(uint64_t, uint64_t);
int32_t fz_text_is_empty(uint64_t, uint64_t);
int32_t fz_text_is_valid(uint64_t, uint64_t);
int32_t fz_text_language(uint64_t, uint64_t, uint64_t, int32_t);
int32_t fz_text_walk(uint64_t, uint64_t, uint64_t, uint64_t);
int32_t fz_tolower(int32_t);
int32_t fz_toupper(int32_t);
int32_t fz_transition_direction(uint64_t);
int32_t fz_transition_outwards(uint64_t);
int32_t fz_transition_type(uint64_t);
int32_t fz_transition_vertical(uint64_t);
int32_t fz_tree_node_child_count(uint64_t, uint64_t);
int32_t fz_tree_node_mcid(uint64_t, uint64_t);
int32_t fz_tree_node_page(uint64_t, uint64_t);
int32_t fz_tree_node_type(uint64_t, uint64_t);
int32_t fz_utflen(const char*);
int32_t fz_write_pixmap_as_data_uri(uint64_t, uint64_t, uint64_t);
int32_t fz_write_pixmap_as_jpeg(uint64_t, uint64_t, uint64_t, int32_t, int32_t);
int32_t fz_write_pixmap_as_pam(uint64_t, uint64_t, uint64_t);
int32_t fz_write_pixmap_as_pbm(uint64_t, uint64_t, uint64_t);
int32_t fz_write_pixmap_as_pkm(uint64_t, uint64_t, uint64_t);
int32_t fz_write_pixmap_as_png(uint64_t, uint64_t, uint64_t);
int32_t fz_write_pixmap_as_pnm(uint64_t, uint64_t, uint64_t);
int32_t fz_write_pixmap_as_ps(uint64_t, uint64_t, uint64_t);
int32_t fz_write_pixmap_as_psd(uint64_t, uint64_t, uint64_t);
int32_t fz_write_ps_file_header(uint64_t, uint64_t);
int32_t fz_write_ps_file_trailer(uint64_t, uint64_t, int32_t);
int32_t fz_xml_att_count(uint64_t, uint64_t);
int32_t fz_xml_child_count(uint64_t, uint64_t);
int32_t fz_xml_find_all(uint64_t, uint64_t, const char*, uint64_t, int32_t);
int32_t fz_xml_is_tag(uint64_t, uint64_t, const char*);
int32_t fz_xml_node_type(uint64_t, uint64_t);
int64_t fz_atoi64(const char*);
int64_t fz_mapped_file_find(uint64_t, uint64_t, const unsigned char*, size_t);
int64_t fz_mapped_file_rfind(uint64_t, uint64_t, const unsigned char*, size_t);
int64_t fz_read_int64(uint64_t, uint64_t);
int64_t fz_read_int64_le(uint64_t, uint64_t);
int64_t fz_tell(uint64_t, uint64_t);
int64_t fz_tell_output(uint64_t, uint64_t);
size_t fz_band_writer_bytes_written(uint64_t, uint64_t);
size_t fz_bidi_get_levels(uint64_t, const uint32_t*, size_t, int32_t, int*, size_t);
size_t fz_bidi_reorder(uint64_t, const char*, char*, size_t, int32_t);
size_t fz_bidi_reorder_run(uint64_t, const uint32_t*, size_t, int32_t, uint32_t*, size_t);
size_t fz_bidi_strip_controls(uint64_t, const uint32_t*, size_t, uint32_t*, size_t);
size_t fz_bitmap_compress_rle(uint64_t, uint64_t, unsigned char*, size_t);
size_t fz_bitmap_compressed_size(uint64_t, uint64_t, int32_t);
size_t fz_bitmap_data_size(uint64_t, uint64_t);
size_t fz_brotli_bound(uint64_t, size_t);
size_t fz_buffer_capacity(uint64_t, uint64_t);
size_t fz_buffer_len(uint64_t, uint64_t);
size_t fz_buffer_pool_count(uint64_t);
size_t fz_buffer_storage(uint64_t, uint64_t, unsigned char*);
size_t fz_buffered_writer_buffered(uint64_t, uint64_t);
size_t fz_cache_line_size(void);
size_t fz_cache_padding(size_t);
size_t fz_casefold(uint64_t, const char*, char*, size_t);
size_t fz_compressed_buffer_size(uint64_t);
size_t fz_copy_option(uint64_t, const char*, char*, size_t);
size_t fz_deflate_bound(uint64_t, size_t);
size_t fz_filter_read(uint64_t, uint64_t, unsigned char*, size_t);
size_t fz_filter_size(uint64_t, uint64_t);
size_t fz_find_line_breaks(uint64_t, const char*, int*, size_t);
size_t fz_find_word_breaks(uint64_t, const char*, int*, size_t);
size_t fz_get_log_buffer_size(uint64_t);
size_t fz_glyph_cache_count(uint64_t);
size_t fz_glyph_cache_max_count(uint64_t);
size_t fz_glyph_cache_max_size(uint64_t);
size_t fz_glyph_cache_memory_size(uint64_t);
size_t fz_heap_capacity(uint64_t, uint64_t);
size_t fz_heap_len(uint64_t, uint64_t);
size_t fz_hyphenation_points(uint64_t, uint64_t, const char*, unsigned char*, size_t);
size_t fz_hyphenator_left_min(uint64_t, uint64_t);
size_t fz_hyphenator_pattern_count(uint64_t, uint64_t);
size_t fz_hyphenator_right_min(uint64_t, uint64_t);
size_t fz_int2_heap_uniq(uint64_t, uint64_t);
size_t fz_int_heap_sort(uint64_t, uint64_t, int*, size_t);
size_t fz_intptr_heap_uniq(uint64_t, uint64_t);
size_t fz_json_escape_string(const char*, char*, size_t);
size_t fz_json_string_length(uint64_t, uint64_t);
size_t fz_json_to_string(uint64_t, uint64_t, char*, size_t);
size_t fz_json_unescape_string(const char*, char*, size_t);
size_t fz_lockfree_queue_capacity(void);
size_t fz_lockfree_queue_len(void);
size_t fz_log_buffer_count(uint64_t);
size_t fz_log_buffer_get(uint64_t, size_t, char*, size_t);
size_t fz_mapped_buffer_position(uint64_t, uint64_t);
size_t fz_mapped_buffer_remaining(uint64_t, uint64_t);
size_t fz_mapped_file_size(uint64_t, uint64_t);
size_t fz_new_font_dict_capacity(void);
size_t fz_new_image_dict_capacity(void);
size_t fz_new_page_dict_capacity(void);
size_t fz_new_resources_dict_capacity(void);
size_t fz_new_stream_dict_capacity(void);
size_t fz_normalize_string(uint64_t, const char*, char*, size_t, int32_t);
size_t fz_page_buffer_capacity(uint64_t, uint64_t);
size_t fz_page_buffer_len(uint64_t, uint64_t);
size_t fz_page_size(void);
size_t fz_pixmap_samples_size(uint64_t, uint64_t);
size_t fz_point_soa_len(uint64_t, uint64_t);
size_t fz_pool_alloc_count(uint64_t, uint64_t);
size_t fz_pool_allocated(uint64_t, uint64_t);
size_t fz_pool_available(uint64_t, uint64_t);
size_t fz_pool_block_count(uint64_t, uint64_t);
size_t fz_pool_high_water(uint64_t, uint64_t);
size_t fz_pool_used(uint64_t, uint64_t);
size_t fz_read(uint64_t, uint64_t, unsigned char*, size_t);
size_t fz_rect_soa_len(uint64_t, uint64_t);
size_t fz_rendered_glyph_cache_purge_font(uint64_t, uint64_t);
size_t fz_round_to_cache_line(size_t);
size_t fz_round_to_page(size_t);
size_t fz_store_count(uint64_t);
size_t fz_store_current_size(uint64_t);
size_t fz_store_evict(uint64_t, size_t);
size_t fz_store_evict_old(uint64_t, uint64_t);
size_t fz_store_evict_type(uint64_t, int32_t);
size_t fz_store_item_size(uint64_t, uint64_t);
size_t fz_store_max_size(uint64_t);
size_t fz_store_size(uint64_t);
size_t fz_store_type_count(uint64_t, int32_t);
size_t fz_store_type_size(uint64_t, int32_t);
size_t fz_string_char_count(uint64_t, const char*);
size_t fz_strlcat(char*, const char*, size_t);
size_t fz_strlcpy(char*, const char*, size_t);
size_t fz_strnlen(const char*, size_t);
size_t fz_tree_get_text_in_order(uint64_t, uint64_t, char*, size_t);
size_t fz_vectored_writer_pending_bytes(uint64_t, uint64_t);
size_t fz_vectored_writer_pending_count(uint64_t, uint64_t);
size_t fz_write_json(uint64_t, uint64_t, char*, size_t);
size_t fz_write_json_pretty(uint64_t, uint64_t, size_t, char*, size_t);
uint16_t fz_read_uint16(uint64_t, uint64_t);
uint16_t fz_read_uint16_le(uint64_t, uint64_t);
uint32_t fz_bidi_get_mirror(uint32_t);
uint32_t fz_glyph_cache_key(uint64_t, uint32_t, float);
uint32_t fz_glyph_id(uint64_t, uint64_t);
uint32_t fz_glyph_unicode(uint64_t, uint64_t);
uint32_t fz_read_uint32(uint64_t, uint64_t);
uint32_t fz_read_uint32_le(uint64_t, uint64_t);
uint64_t fz_aa_level(uint64_t);
uint64_t fz_auto_deskew_pixmap(uint64_t, uint64_t, int32_t);
uint64_t fz_begin_page(uint64_t, uint64_t, float, float, float, float);
uint64_t fz_black_box_int(uint64_t);
uint64_t fz_brotli_to_buffer(uint64_t, const unsigned char*, size_t, int32_t);
uint64_t fz_buffer_extract(uint64_t, uint64_t);
uint64_t fz_buffer_is_pooled(uint64_t, uint64_t);
uint64_t fz_buffer_pool_stats(uint64_t);
uint64_t fz_buffered_flush(uint64_t, uint64_t);
uint64_t fz_buffered_sync(uint64_t, uint64_t);
uint64_t fz_buffered_write(uint64_t, uint64_t, const unsigned char*, size_t);
uint64_t fz_buffered_write_string(uint64_t, uint64_t, const char*);
uint64_t fz_buffered_writer_stats(uint64_t, uint64_t);
uint64_t fz_caught(uint64_t);
uint64_t fz_clone_archive(uint64_t, uint64_t);
uint64_t fz_clone_buffer(uint64_t, uint64_t);
uint64_t fz_clone_colorspace(uint64_t, uint64_t);
uint64_t fz_clone_context(uint64_t);
uint64_t fz_clone_cookie(uint64_t, uint64_t);
uint64_t fz_clone_default_colorspaces(uint64_t, uint64_t);
uint64_t fz_clone_display_list(uint64_t, uint64_t);
uint64_t fz_clone_document(uint64_t, uint64_t);
uint64_t fz_clone_font(uint64_t, uint64_t);
uint64_t fz_clone_image(uint64_t, uint64_t);
uint64_t fz_clone_link(uint64_t, uint64_t);
uint64_t fz_clone_link_list(uint64_t, uint64_t);
uint64_t fz_clone_path(uint64_t, uint64_t);
uint64_t fz_clone_pixmap(uint64_t, uint64_t);
uint64_t fz_clone_separations(uint64_t, uint64_t);
uint64_t fz_clone_stroke_state(uint64_t, uint64_t);
uint64_t fz_clone_text(uint64_t, uint64_t);
uint64_t fz_colorspace_base(uint64_t, uint64_t);
uint64_t fz_compress_ccitt_fax_g3(uint64_t, const unsigned char*, int32_t, int32_t, ssize_t);
uint64_t fz_compress_ccitt_fax_g4(uint64_t, const unsigned char*, int32_t, int32_t, ssize_t);
uint64_t fz_compressed_buffer_get_data(uint64_t, uint64_t);
uint64_t fz_conformance_error_count(uint64_t, uint64_t);
uint64_t fz_conformance_is_valid(uint64_t, uint64_t);
uint64_t fz_conformance_issue_count(uint64_t, uint64_t);
uint64_t fz_conformance_pdf2_compliant(uint64_t, uint64_t);
uint64_t fz_conformance_pdf_version(uint64_t, uint64_t);
uint64_t fz_conformance_pdfa_claimed(uint64_t, uint64_t);
uint64_t fz_conformance_pdfa_valid(uint64_t, uint64_t);
uint64_t fz_conformance_pdfx_claimed(uint64_t, uint64_t);
uint64_t fz_conformance_pdfx_valid(uint64_t, uint64_t);
uint64_t fz_conformance_warning_count(uint64_t, uint64_t);
uint64_t fz_context_is_valid(uint64_t);
uint64_t fz_create_link(uint64_t, fz_rect, const char*);
uint64_t fz_decode_image(uint64_t, uint64_t, int32_t, fz_irect);
uint64_t fz_decode_image_scaled(uint64_t, uint64_t, int32_t, int32_t, int32_t, fz_irect);
uint64_t fz_default_cmyk(uint64_t, uint64_t);
uint64_t fz_default_color_params(void);
uint64_t fz_default_gray(uint64_t, uint64_t);
uint64_t fz_default_output_intent(uint64_t, uint64_t);
uint64_t fz_default_rgb(uint64_t, uint64_t);
uint64_t fz_deflate_to_buffer(uint64_t, const unsigned char*, size_t, int32_t);
uint64_t fz_deskew_pixmap(uint64_t, uint64_t, double, int32_t);
uint64_t fz_device_bgr(uint64_t);
uint64_t fz_device_cmyk(uint64_t);
uint64_t fz_device_gray(uint64_t);
uint64_t fz_device_grayscale(uint64_t);
uint64_t fz_device_lab(uint64_t);
uint64_t fz_device_rgb(uint64_t);
uint64_t fz_device_srgb(uint64_t);
uint64_t fz_device_type(uint64_t, uint64_t);
uint64_t fz_draw_device_target(uint64_t, uint64_t);
uint64_t fz_fits_in_cache_lines(size_t, size_t);
uint64_t fz_flip_pixmap_horizontal(uint64_t, uint64_t);
uint64_t fz_flip_pixmap_vertical(uint64_t, uint64_t);
uint64_t fz_get_pixmap_from_image(uint64_t, uint64_t, fz_irect, fz_matrix, int*, int*);
uint64_t fz_glyph_cache_evictions(uint64_t);
uint64_t fz_glyph_cache_hits(uint64_t);
uint64_t fz_glyph_cache_lookup(uint64_t, uint64_t, uint32_t, uint32_t);
uint64_t fz_glyph_cache_misses(uint64_t);
uint64_t fz_glyph_cache_purges(uint64_t);
uint64_t fz_glyph_font(uint64_t, uint64_t);
uint64_t fz_gpu_create_buffer(uint64_t, int32_t, int32_t);
uint64_t fz_gpu_create_device(int32_t);
uint64_t fz_gpu_create_texture(uint64_t, int32_t, int32_t, int32_t);
uint64_t fz_has_error(uint64_t);
uint64_t fz_has_simd(void);
uint64_t fz_hash_pdf_name(const char*);
uint64_t fz_image_colorspace(uint64_t, uint64_t);
uint64_t fz_image_type_name(int32_t);
uint64_t fz_is_cache_aligned(uint64_t);
uint64_t fz_is_page_aligned(uint64_t);
uint64_t fz_is_standard_name(const char*);
uint64_t fz_jbig2_globals_data(uint64_t, uint64_t);
uint64_t fz_json_array_get(uint64_t, uint64_t, int32_t);
uint64_t fz_json_new_array(uint64_t, uint64_t);
uint64_t fz_json_new_boolean(uint64_t, uint64_t, int32_t);
uint64_t fz_json_new_null(uint64_t, uint64_t);
uint64_t fz_json_new_number(uint64_t, uint64_t, double);
uint64_t fz_json_new_object(uint64_t, uint64_t);
uint64_t fz_json_new_string(uint64_t, uint64_t, const char*);
uint64_t fz_json_object_get(uint64_t, uint64_t, const char*);
uint64_t fz_keep_archive(uint64_t, uint64_t);
uint64_t fz_keep_band_writer(uint64_t, uint64_t);
uint64_t fz_keep_bitmap(uint64_t, uint64_t);
uint64_t fz_keep_buffer(uint64_t, uint64_t);
uint64_t fz_keep_colorspace(uint64_t, uint64_t);
uint64_t fz_keep_compressed_buffer(uint64_t, uint64_t);
uint64_t fz_keep_context(uint64_t);
uint64_t fz_keep_cookie(uint64_t, uint64_t);
uint64_t fz_keep_default_colorspaces(uint64_t, uint64_t);
uint64_t fz_keep_device(uint64_t, uint64_t);
uint64_t fz_keep_display_list(uint64_t, uint64_t);
uint64_t fz_keep_document(uint64_t, uint64_t);
uint64_t fz_keep_draw_device(uint64_t, uint64_t);
uint64_t fz_keep_font(uint64_t, uint64_t);
uint64_t fz_keep_glyph(uint64_t, uint64_t);
uint64_t fz_keep_image(uint64_t, uint64_t);
uint64_t fz_keep_jbig2_globals(uint64_t, uint64_t);
uint64_t fz_keep_link(uint64_t, uint64_t);
uint64_t fz_keep_outline(uint64_t, uint64_t);
uint64_t fz_keep_output(uint64_t, uint64_t);
uint64_t fz_keep_page(uint64_t, uint64_t);
uint64_t fz_keep_path(uint64_t, uint64_t);
uint64_t fz_keep_pixmap(uint64_t, uint64_t);
uint64_t fz_keep_pool(uint64_t, uint64_t);
uint64_t fz_keep_separations(uint64_t, uint64_t);
uint64_t fz_keep_shade(uint64_t, uint64_t);
uint64_t fz_keep_stext_page(uint64_t, uint64_t);
uint64_t fz_keep_stream(uint64_t, uint64_t);
uint64_t fz_keep_stroke_state(uint64_t, uint64_t);
uint64_t fz_keep_structure_tree(uint64_t, uint64_t);
uint64_t fz_keep_text(uint64_t, uint64_t);
uint64_t fz_layout_matrix(void);
uint64_t fz_layout_point(void);
uint64_t fz_layout_quad(void);
uint64_t fz_layout_rect(void);
uint64_t fz_likely(uint64_t);
uint64_t fz_link_list_find_at_point(uint64_t, uint64_t, float, float);
uint64_t fz_link_list_first(uint64_t, uint64_t);
uint64_t fz_link_list_get(uint64_t, uint64_t, int32_t);
uint64_t fz_load_chapter_page(uint64_t, uint64_t, int32_t, int32_t);
uint64_t fz_load_jbig2_globals(uint64_t, uint64_t);
uint64_t fz_load_outline(uint64_t, uint64_t);
uint64_t fz_load_outline_from_iterator(uint64_t, uint64_t);
uint64_t fz_load_page(uint64_t, uint64_t, int32_t);
uint64_t fz_locality_stats(uint64_t);
uint64_t fz_lockfree_queue_is_empty(void);
uint64_t fz_lockfree_queue_pop(void);
uint64_t fz_lockfree_queue_push(uint64_t);
uint64_t fz_log_warning_callback(uint64_t, void*);
uint64_t fz_lookup_hyphenator(uint64_t, int32_t);
uint64_t fz_lookup_standard_name(const char*);
uint64_t fz_mapped_buffer_read(uint64_t, uint64_t, unsigned char*, size_t);
uint64_t fz_mapped_buffer_read_byte(uint64_t, uint64_t);
uint64_t fz_mapped_file_advise(uint64_t, uint64_t, uint64_t);
uint64_t fz_mapped_file_read(uint64_t, uint64_t, size_t, unsigned char*, size_t);
uint64_t fz_mapped_file_stats(uint64_t, uint64_t);
uint64_t fz_matrix_determinant(fz_matrix);
uint64_t fz_matrix_expansion(fz_matrix);
uint64_t fz_matrix_max_expansion(fz_matrix);
uint64_t fz_new_band_writer(uint64_t, uint64_t, int32_t);
uint64_t fz_new_band_writer_with_config(uint64_t, uint64_t, int32_t, int32_t, int32_t, int32_t, int32_t);
uint64_t fz_new_barcode_image(uint64_t, int32_t, const char*, int32_t, int32_t, int32_t, int32_t);
uint64_t fz_new_barcode_pixmap(uint64_t, int32_t, const char*, int32_t, int32_t, int32_t, int32_t);
uint64_t fz_new_bbox_device(uint64_t, fz_rect);
uint64_t fz_new_bitmap(uint64_t, int32_t, int32_t, int32_t, int32_t);
uint64_t fz_new_bitmap_from_pixmap(uint64_t, uint64_t, int32_t);
uint64_t fz_new_bitmap_from_pixmap_halftone(uint64_t, uint64_t, int32_t);
uint64_t fz_new_blinds_transition(float, int32_t);
uint64_t fz_new_box_transition(float, int32_t);
uint64_t fz_new_buffer(uint64_t, size_t);
uint64_t fz_new_buffer_from_copied_data(uint64_t, const unsigned char*, size_t);
uint64_t fz_new_buffer_from_data(uint64_t, unsigned char*, size_t);
uint64_t fz_new_buffer_from_pixmap_as_jpeg(uint64_t, uint64_t, int32_t, int32_t);
uint64_t fz_new_buffer_from_pixmap_as_pam(uint64_t, uint64_t);
uint64_t fz_new_buffer_from_pixmap_as_pbm(uint64_t, uint64_t);
uint64_t fz_new_buffer_from_pixmap_as_pkm(uint64_t, uint64_t);
uint64_t fz_new_buffer_from_pixmap_as_png(uint64_t, uint64_t);
uint64_t fz_new_buffer_from_pixmap_as_pnm(uint64_t, uint64_t);
uint64_t fz_new_buffer_from_pixmap_as_psd(uint64_t, uint64_t);
uint64_t fz_new_buffer_from_stext_page(uint64_t, uint64_t);
uint64_t fz_new_buffer_unpooled(uint64_t, size_t);
uint64_t fz_new_buffer_with_capacity(uint64_t, size_t);
uint64_t fz_new_buffered_writer(uint64_t, const char*);
uint64_t fz_new_buffered_writer_with_capacity(uint64_t, const char*, size_t);
uint64_t fz_new_cal_gray_colorspace(uint64_t, const float*, const float*, float);
uint64_t fz_new_cal_rgb_colorspace(uint64_t, const float*, const float*, const float*, const float*);
uint64_t fz_new_cbz_writer(uint64_t, const char*, const char*);
uint64_t fz_new_cbz_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_color_params(int32_t, int32_t, int32_t, int32_t);
uint64_t fz_new_compressed_buffer(uint64_t);
uint64_t fz_new_conformance_validator(uint64_t, uint64_t, uint64_t, uint64_t);
uint64_t fz_new_cookie(uint64_t);
uint64_t fz_new_cover_transition(float, int32_t);
uint64_t fz_new_csv_writer(uint64_t, const char*, const char*);
uint64_t fz_new_csv_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_default_colorspaces(uint64_t);
uint64_t fz_new_default_context(void);
uint64_t fz_new_device_n_colorspace(uint64_t, uint64_t, int32_t, const const char*);
uint64_t fz_new_display_list(uint64_t, float, float, float, float);
uint64_t fz_new_dissolve_transition(float);
uint64_t fz_new_document_writer(uint64_t, const char*, const char*, const char*);
uint64_t fz_new_document_writer_with_buffer(uint64_t, uint64_t, const char*, const char*);
uint64_t fz_new_document_writer_with_output(uint64_t, uint64_t, const char*, const char*);
uint64_t fz_new_docx_writer(uint64_t, const char*, const char*);
uint64_t fz_new_docx_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_draw_device(uint64_t, fz_matrix, uint64_t);
uint64_t fz_new_draw_device_with_matrix(uint64_t, uint64_t, const float*);
uint64_t fz_new_draw_device_with_options(uint64_t, uint64_t, int32_t, int32_t);
uint64_t fz_new_draw_device_with_size(uint64_t, uint64_t, int32_t, int32_t);
uint64_t fz_new_empty_hyphenator(uint64_t);
uint64_t fz_new_fade_transition(float);
uint64_t fz_new_fly_transition(float, int32_t, int32_t);
uint64_t fz_new_font(uint64_t, uint64_t, int32_t, int32_t, uint64_t);
uint64_t fz_new_font_from_file(uint64_t, uint64_t, uint64_t, int32_t, int32_t);
uint64_t fz_new_font_from_memory(uint64_t, uint64_t, const unsigned char*, int32_t, int32_t, int32_t);
uint64_t fz_new_function_shade(uint64_t, uint64_t, const float*, const float*);
uint64_t fz_new_glitter_transition(float, int32_t);
uint64_t fz_new_glyph(uint64_t, uint64_t, uint32_t, uint32_t);
uint64_t fz_new_glyph_at(uint64_t, uint64_t, uint32_t, float, float);
uint64_t fz_new_glyph_with_matrix(uint64_t, uint64_t, uint32_t, const float*);
uint64_t fz_new_heap(uint64_t, int32_t);
uint64_t fz_new_heap_with_capacity(uint64_t, int32_t, size_t);
uint64_t fz_new_hyphenator(uint64_t, int32_t);
uint64_t fz_new_image_from_buffer(uint64_t, uint64_t);
uint64_t fz_new_image_from_data(uint64_t, int32_t, int32_t, int32_t, uint64_t, int32_t, int32_t, int32_t, int32_t, const float*, const unsigned char*, const unsigned char*, int32_t);
uint64_t fz_new_image_from_file(uint64_t, uint64_t);
uint64_t fz_new_image_from_pixmap(uint64_t, uint64_t, uint64_t);
uint64_t fz_new_indexed_colorspace(uint64_t, uint64_t, int32_t, const unsigned char*);
uint64_t fz_new_jpeg_pixmap_writer(uint64_t, const char*, const char*);
uint64_t fz_new_linear_shade(uint64_t, uint64_t, float, float, float, float, int32_t, int32_t);
uint64_t fz_new_link_list(uint64_t);
uint64_t fz_new_list_device(uint64_t, uint64_t);
uint64_t fz_new_mapped_buffer(uint64_t, const char*);
uint64_t fz_new_mesh_shade(uint64_t, uint64_t, int32_t, int32_t, int32_t, int32_t);
uint64_t fz_new_ocr_engine(uint64_t, uint64_t);
uint64_t fz_new_ocr_result(uint64_t, uint32_t, uint32_t);
uint64_t fz_new_odt_writer(uint64_t, const char*, const char*);
uint64_t fz_new_odt_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_outline(uint64_t);
uint64_t fz_new_outline_iterator(uint64_t);
uint64_t fz_new_output_with_buffer(uint64_t, uint64_t);
uint64_t fz_new_output_with_path(uint64_t, const char*, int32_t);
uint64_t fz_new_page_aligned_buffer(uint64_t, size_t);
uint64_t fz_new_pam_pixmap_writer(uint64_t, const char*, const char*);
uint64_t fz_new_path(uint64_t);
uint64_t fz_new_pbm_pixmap_writer(uint64_t, const char*, const char*);
uint64_t fz_new_pcl_writer(uint64_t, const char*, const char*);
uint64_t fz_new_pcl_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_pclm_writer(uint64_t, const char*, const char*);
uint64_t fz_new_pclm_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_pdf_writer(uint64_t, const char*, const char*);
uint64_t fz_new_pdf_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_pdfocr_writer(uint64_t, const char*, const char*);
uint64_t fz_new_pdfocr_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_pgm_pixmap_writer(uint64_t, const char*, const char*);
uint64_t fz_new_pixmap(uint64_t, uint64_t, int32_t, int32_t, uint64_t, int32_t);
uint64_t fz_new_pixmap_from_page(uint64_t, uint64_t, fz_matrix, uint64_t, int32_t);
uint64_t fz_new_pixmap_with_bbox(uint64_t, uint64_t, fz_irect, uint64_t, int32_t);
uint64_t fz_new_pkm_pixmap_writer(uint64_t, const char*, const char*);
uint64_t fz_new_png_pixmap_writer(uint64_t, const char*, const char*);
uint64_t fz_new_pnm_pixmap_writer(uint64_t, const char*, const char*);
uint64_t fz_new_point_soa(uint64_t, size_t);
uint64_t fz_new_pool(uint64_t);
uint64_t fz_new_pool_named(uint64_t, uint64_t);
uint64_t fz_new_pool_with_size(uint64_t, size_t);
uint64_t fz_new_ppm_pixmap_writer(uint64_t, const char*, const char*);
uint64_t fz_new_ps_writer(uint64_t, const char*, const char*);
uint64_t fz_new_ps_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_push_transition(float, int32_t);
uint64_t fz_new_pwg_writer(uint64_t, const char*, const char*);
uint64_t fz_new_pwg_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_radial_shade(uint64_t, uint64_t, float, float, float, float, float, float, int32_t, int32_t);
uint64_t fz_new_rect_soa(uint64_t, size_t);
uint64_t fz_new_render_task(uint64_t, uint64_t);
uint64_t fz_new_separations(uint64_t, int32_t);
uint64_t fz_new_split_transition(float, int32_t, int32_t);
uint64_t fz_new_stext_page(uint64_t, float, float, float, float);
uint64_t fz_new_stext_page_from_page(uint64_t, uint64_t, uint64_t);
uint64_t fz_new_story(uint64_t, uint64_t, const char*, float, uint64_t);
uint64_t fz_new_stroke_state(uint64_t);
uint64_t fz_new_stroke_state_with_len(uint64_t, int32_t, float);
uint64_t fz_new_structure_tree(uint64_t);
uint64_t fz_new_svg_writer(uint64_t, const char*, const char*);
uint64_t fz_new_svg_writer_with_output(uint64_t, uint64_t, const char*);
uint64_t fz_new_table(uint64_t, float, float, float, float);
uint64_t fz_new_table_detector(uint64_t, uint64_t, uint64_t, float);
uint64_t fz_new_text(uint64_t);
uint64_t fz_new_text_writer(uint64_t, const char*, const char*, const char*);
uint64_t fz_new_text_writer_with_output(uint64_t, const char*, uint64_t, const char*);
uint64_t fz_new_tile_renderer(uint64_t, float, float, float, float, uint32_t, uint32_t, float, uint64_t);
uint64_t fz_new_trace_device(uint64_t);
uint64_t fz_new_transition(int32_t, float);
uint64_t fz_new_uncover_transition(float, int32_t);
uint64_t fz_new_validation_result(uint64_t);
uint64_t fz_new_vectored_writer(uint64_t, const char*);
uint64_t fz_new_wipe_transition(float, int32_t);
uint64_t fz_new_xml_document(uint64_t);
uint64_t fz_ocr_engine_init(uint64_t, uint64_t);
uint64_t fz_ocr_engine_is_initialized(uint64_t, uint64_t);
uint64_t fz_ocr_engine_set_language(uint64_t, uint64_t, const char*);
uint64_t fz_ocr_is_available(uint64_t, uint64_t);
uint64_t fz_ocr_result_confidence(uint64_t, uint64_t);
uint64_t fz_ocr_result_line_count(uint64_t, uint64_t);
uint64_t fz_ocr_result_word_count(uint64_t, uint64_t);
uint64_t fz_open_a85d(uint64_t, uint64_t);
uint64_t fz_open_aesd(uint64_t, uint64_t, const unsigned char*, uint32_t);
uint64_t fz_open_ahxd(uint64_t, uint64_t);
uint64_t fz_open_arc4(uint64_t, uint64_t, const unsigned char*, uint32_t);
uint64_t fz_open_archive(uint64_t, const char*);
uint64_t fz_open_archive_with_buffer(uint64_t, const unsigned char*, size_t);
uint64_t fz_open_brotlid(uint64_t, uint64_t);
uint64_t fz_open_buffer(uint64_t, uint64_t);
uint64_t fz_open_concat(uint64_t, int32_t, int32_t);
uint64_t fz_open_dctd(uint64_t, uint64_t, int32_t, int32_t, int32_t, uint64_t);
uint64_t fz_open_document(uint64_t, const char*);
uint64_t fz_open_document_with_buffer(uint64_t, const char*, const unsigned char*, size_t);
uint64_t fz_open_document_with_stream(uint64_t, const char*, uint64_t);
uint64_t fz_open_endstream_filter(uint64_t, uint64_t, uint64_t, int64_t);
uint64_t fz_open_faxd(uint64_t, uint64_t, int32_t, int32_t, int32_t, int32_t, int32_t, int32_t, int32_t);
uint64_t fz_open_file(uint64_t, const char*);
uint64_t fz_open_flated(uint64_t, uint64_t, int32_t);
uint64_t fz_open_jbig2d(uint64_t, uint64_t, uint64_t, int32_t);
uint64_t fz_open_libarchived(uint64_t, uint64_t);
uint64_t fz_open_lzwd(uint64_t, uint64_t, int32_t, int32_t, int32_t, int32_t);
uint64_t fz_open_mapped_file(uint64_t, const char*);
uint64_t fz_open_memory(uint64_t, const unsigned char*, size_t);
uint64_t fz_open_null_filter(uint64_t, uint64_t, uint64_t, int64_t);
uint64_t fz_open_predict(uint64_t, uint64_t, int32_t, int32_t, int32_t, int32_t);
uint64_t fz_open_range_filter(uint64_t, uint64_t, const void*, int32_t);
uint64_t fz_open_rld(uint64_t, uint64_t);
uint64_t fz_open_sgilog16(uint64_t, uint64_t, int32_t);
uint64_t fz_open_sgilog24(uint64_t, uint64_t, int32_t);
uint64_t fz_open_sgilog32(uint64_t, uint64_t, int32_t);
uint64_t fz_open_thunder(uint64_t, uint64_t, int32_t);
uint64_t fz_outline_down(uint64_t, uint64_t);
uint64_t fz_outline_glyph(uint64_t, uint64_t, int32_t, fz_matrix);
uint64_t fz_outline_iterator_from_outline(uint64_t, uint64_t);
uint64_t fz_outline_next(uint64_t, uint64_t);
uint64_t fz_page_buffer_read(uint64_t, uint64_t, size_t, unsigned char*, size_t);
uint64_t fz_page_buffer_write(uint64_t, uint64_t, const unsigned char*, size_t);
uint64_t fz_parse_json(uint64_t, uint64_t, const char*);
uint64_t fz_parse_xml(uint64_t, const char*, int32_t);
uint64_t fz_parse_xml_from_buffer(uint64_t, uint64_t, int32_t);
uint64_t fz_pdfocr_writer_set_progress(uint64_t, uint64_t, uint64_t);
uint64_t fz_pixmap_colorspace(uint64_t, uint64_t);
uint64_t fz_pool_strdup(uint64_t, uint64_t, uint64_t);
uint64_t fz_profiler_current_bytes(void);
uint64_t fz_profiler_handle_count_by_type(uint64_t);
uint64_t fz_profiler_live_handle_count(void);
uint64_t fz_profiler_peak_bytes(void);
uint64_t fz_profiler_peak_handles(void);
uint64_t fz_profiler_potential_leak_count(uint64_t);
uint64_t fz_read_all(uint64_t, uint64_t);
uint64_t fz_read_archive_entry(uint64_t, uint64_t, const char*);
uint64_t fz_read_uint64(uint64_t, uint64_t);
uint64_t fz_read_uint64_le(uint64_t, uint64_t);
uint64_t fz_rect_area(fz_rect);
uint64_t fz_rect_height(fz_rect);
uint64_t fz_rect_width(fz_rect);
uint64_t fz_render_glyph_pixmap(uint64_t, uint64_t, int32_t, const void*, const void*, int32_t);
uint64_t fz_render_task_is_cancelled(uint64_t, uint64_t);
uint64_t fz_rendered_glyph_cache_lookup(uint64_t, uint64_t, int32_t, const void*, uint8_t, uint8_t, int32_t);
uint64_t fz_rotate_pixmap(uint64_t, uint64_t, double, int32_t);
uint64_t fz_rotate_pixmap_90(uint64_t, uint64_t, int32_t);
uint64_t fz_scale_pixmap(uint64_t, uint64_t, float, float);
uint64_t fz_shade_colorspace(uint64_t, uint64_t);
uint64_t fz_simd_buffer_copy(unsigned char*, const unsigned char*, size_t);
uint64_t fz_simd_buffer_equal(const unsigned char*, const unsigned char*, size_t);
uint64_t fz_simd_buffer_fill(unsigned char*, size_t, uint8_t);
uint64_t fz_simd_cmyk_to_rgb(uint64_t, uint64_t, uint64_t, uint64_t);
uint64_t fz_simd_features(void);
uint64_t fz_simd_level(void);
uint64_t fz_simd_matrix_concat(uint64_t, uint64_t);
uint64_t fz_simd_rgb_to_cmyk(uint64_t, uint64_t, uint64_t);
uint64_t fz_simd_rgb_to_gray(uint64_t, uint64_t, uint64_t);
uint64_t fz_simd_transform_point(uint64_t, uint64_t, uint64_t);
uint64_t fz_simd_transform_points(void*, size_t, uint64_t);
uint64_t fz_slice_buffer(uint64_t, uint64_t, size_t, size_t);
uint64_t fz_standard_name_count(void);
uint64_t fz_store_find(uint64_t, const unsigned char*, size_t);
uint64_t fz_store_find_by_id(uint64_t, uint64_t);
uint64_t fz_store_hits(uint64_t);
uint64_t fz_store_item(uint64_t, int32_t, uint64_t, size_t, const unsigned char*, size_t);
uint64_t fz_store_item_access_count(uint64_t, uint64_t);
uint64_t fz_store_item_age(uint64_t, uint64_t);
uint64_t fz_store_keep(uint64_t, uint64_t);
uint64_t fz_store_misses(uint64_t);
uint64_t fz_store_remove(uint64_t, uint64_t);
uint64_t fz_store_remove_by_key(uint64_t, const unsigned char*, size_t);
uint64_t fz_store_scavenge(uint64_t, size_t, void*);
uint64_t fz_store_total_evicted(uint64_t);
uint64_t fz_store_total_stored(uint64_t);
uint64_t fz_story_document(uint64_t, uint64_t);
uint64_t fz_table_col_count(uint64_t, uint64_t);
uint64_t fz_table_detector_count(uint64_t, uint64_t);
uint64_t fz_table_row_count(uint64_t, uint64_t);
uint64_t fz_tile_renderer_count(uint64_t, uint64_t);
uint64_t fz_tile_renderer_get_bounds(uint64_t, uint64_t, uint64_t, float*, float*, float*, float*);
uint64_t fz_tile_renderer_is_complete(uint64_t, uint64_t);
uint64_t fz_tree_add_node(uint64_t, uint64_t, uint64_t, int32_t);
uint64_t fz_tree_find_by_id(uint64_t, uint64_t, const char*);
uint64_t fz_tree_node_child(uint64_t, uint64_t, int32_t);
uint64_t fz_tree_node_first_child(uint64_t, uint64_t);
uint64_t fz_tree_node_parent(uint64_t, uint64_t);
uint64_t fz_tree_root(uint64_t, uint64_t);
uint64_t fz_unlikely(uint64_t);
uint64_t fz_unshare_stroke_state(uint64_t, uint64_t);
uint64_t fz_validation_issue_severity(uint64_t, uint64_t, uint64_t);
uint64_t fz_vectored_flush(uint64_t, uint64_t);
uint64_t fz_vectored_queue(uint64_t, uint64_t, const unsigned char*, size_t);
uint64_t fz_vectored_sync(uint64_t, uint64_t);
uint64_t fz_vectored_writer_stats(uint64_t, uint64_t);
uint64_t fz_version(void);
uint64_t fz_xml_down(uint64_t, uint64_t);
uint64_t fz_xml_find(uint64_t, uint64_t, const char*);
uint64_t fz_xml_next(uint64_t, uint64_t);
uint64_t fz_xml_prev(uint64_t, uint64_t);
uint64_t fz_xml_root(uint64_t, uint64_t);
uint64_t fz_xml_up(uint64_t, uint64_t);
uint8_t fz_get_pixmap_sample(uint64_t, uint64_t, int32_t, int32_t, int32_t);
unsigned char* fz_new_brotli_data(uint64_t, size_t*, const unsigned char*, size_t, int32_t);
unsigned char* fz_new_brotli_data_from_buffer(uint64_t, size_t*, uint64_t, int32_t);
unsigned char* fz_new_deflated_data(uint64_t, size_t*, const unsigned char*, size_t, int32_t);
unsigned char* fz_new_deflated_data_from_buffer(uint64_t, size_t*, uint64_t, int32_t);
unsigned char* fz_pixmap_samples(uint64_t, uint64_t);
unsigned char* fz_pool_alloc(uint64_t, uint64_t, size_t);
unsigned char* fz_pool_alloc_aligned(uint64_t, uint64_t, size_t, size_t);
unsigned char* fz_pool_calloc(uint64_t, uint64_t, size_t, size_t);
void fz_abort_cookie(uint64_t, uint64_t);
void fz_append_base64(uint64_t, uint64_t, const unsigned char*, size_t, int32_t);
void fz_append_bits(uint64_t, uint64_t, int32_t, int32_t);
void fz_append_bits_pad(uint64_t, uint64_t);
void fz_append_buffer(uint64_t, uint64_t, uint64_t);
void fz_append_byte(uint64_t, uint64_t, uint64_t);
void fz_append_data(uint64_t, uint64_t, const void*, size_t);
void fz_append_float(uint64_t, uint64_t, float, int32_t);
void fz_append_hex(uint64_t, uint64_t, const unsigned char*, size_t);
void fz_append_int(uint64_t, uint64_t, int64_t);
void fz_append_int16_be(uint64_t, uint64_t, int16_t);
void fz_append_int16_le(uint64_t, uint64_t, int16_t);
void fz_append_int32_be(uint64_t, uint64_t, int32_t);
void fz_append_int32_le(uint64_t, uint64_t, int32_t);
void fz_append_pdf_string(uint64_t, uint64_t, const char*);
void fz_append_rune(uint64_t, uint64_t, int32_t);
void fz_append_string(uint64_t, uint64_t, const char*);
void fz_assume(uint64_t);
void fz_band_writer_set_components(uint64_t, uint64_t, int32_t, int32_t);
void fz_band_writer_set_compression(uint64_t, uint64_t, int32_t);
void fz_band_writer_set_dimensions(uint64_t, uint64_t, int32_t, int32_t);
void fz_band_writer_set_jpeg_quality(uint64_t, uint64_t, int32_t);
void fz_band_writer_set_page_info(uint64_t, uint64_t, int32_t, int32_t);
void fz_band_writer_set_progress(uint64_t, uint64_t, uint64_t, uint64_t);
void fz_band_writer_set_res(uint64_t, uint64_t, int32_t, int32_t);
void fz_band_writer_set_rows_per_band(uint64_t, uint64_t, int32_t);
void fz_begin_group(uint64_t, uint64_t, fz_rect, uint64_t, int32_t, int32_t, int32_t, float);
void fz_begin_mask(uint64_t, uint64_t, fz_rect, int32_t, uint64_t, const float*);
void fz_bidi_fragment_text(uint64_t, const uint32_t*, size_t, int*, uint64_t, void*, int32_t);
void fz_bitmap_clear(uint64_t, uint64_t);
void fz_bitmap_fill(uint64_t, uint64_t);
void fz_bitmap_invert(uint64_t, uint64_t);
void fz_bitmap_set_pixel(uint64_t, uint64_t, int32_t, int32_t, int32_t);
void fz_bitmap_set_res(uint64_t, uint64_t, int32_t, int32_t);
void fz_buffer_pool_clear(uint64_t);
void fz_buffer_reserve(uint64_t, uint64_t, size_t);
void fz_buffer_shrink_to_fit(uint64_t, uint64_t);
void fz_cancel_render_task(uint64_t, uint64_t);
void fz_clamp_color(uint64_t, uint64_t, const float*, float*);
void fz_clear_buffer(uint64_t, uint64_t);
void fz_clear_module_log_level(uint64_t, const char*);
void fz_clear_pixmap(uint64_t, uint64_t);
void fz_clear_pixmap_with_value(uint64_t, uint64_t, int32_t);
void fz_clear_text(uint64_t, uint64_t);
void fz_clip_image_mask(uint64_t, uint64_t, uint64_t, fz_matrix);
void fz_clip_path(uint64_t, uint64_t, uint64_t, int32_t, fz_matrix);
void fz_clip_stroke_path(uint64_t, uint64_t, uint64_t, uint64_t, fz_matrix);
void fz_clip_stroke_text(uint64_t, uint64_t, uint64_t, uint64_t, fz_matrix);
void fz_clip_text(uint64_t, uint64_t, uint64_t, fz_matrix);
void fz_close_device(uint64_t, uint64_t);
void fz_close_document_writer(uint64_t, uint64_t);
void fz_close_mapped_file(uint64_t, uint64_t);
void fz_close_output(uint64_t, uint64_t);
void fz_closepath(uint64_t, uint64_t);
void fz_colorspace_digest(uint64_t, uint64_t, unsigned char*);
void fz_compress_brotli(uint64_t, unsigned char*, size_t*, const unsigned char*, size_t, int32_t);
void fz_compressed_buffer_set_data(uint64_t, uint64_t, uint64_t);
void fz_compressed_buffer_set_type(uint64_t, uint64_t, int32_t);
void fz_concat_push_drop(uint64_t, uint64_t, uint64_t);
void fz_conformance_validator_reset(uint64_t, uint64_t);
void fz_convert_color(uint64_t, uint64_t, const float*, uint64_t, float*, uint64_t);
void fz_convert_color_with_params(uint64_t, uint64_t, const float*, uint64_t, float*, uint64_t, uint64_t);
void fz_convert_pixel(uint64_t, uint64_t, const float*, uint64_t, float*);
void fz_convert_pixmap(uint64_t, uint64_t, uint64_t, uint64_t);
void fz_convert_separation_colors(uint64_t, uint64_t, const float*, int32_t, float*, int32_t);
void fz_cookie_abort(uint64_t, uint64_t);
void fz_cookie_inc_errors(uint64_t, uint64_t);
void fz_cookie_inc_progress(uint64_t, uint64_t);
void fz_cookie_reset(uint64_t, uint64_t);
void fz_cookie_reset_abort(uint64_t, uint64_t);
void fz_cookie_set_errors(uint64_t, uint64_t, int32_t);
void fz_cookie_set_incomplete(uint64_t, uint64_t, int32_t);
void fz_cookie_set_progress(uint64_t, uint64_t, int32_t);
void fz_cookie_set_progress_max(uint64_t, uint64_t, int32_t);
void fz_curveto(uint64_t, uint64_t, float, float, float, float, float, float);
void fz_deflate(uint64_t, unsigned char*, size_t*, const unsigned char*, size_t, int32_t);
void fz_dirname(char*, const char*, size_t);
void fz_disable_all_separations(uint64_t, uint64_t);
void fz_disable_device_hints(uint64_t, uint64_t, int32_t);
void fz_disable_icc(uint64_t);
void fz_display_list_clear(uint64_t, uint64_t);
void fz_draw_device_begin_mask(uint64_t, uint64_t, const float*, int32_t);
void fz_draw_device_begin_path(uint64_t, uint64_t);
void fz_draw_device_begin_pattern(uint64_t, uint64_t, uint64_t, const float*);
void fz_draw_device_begin_text(uint64_t, uint64_t);
void fz_draw_device_clip(uint64_t, uint64_t, int32_t);
void fz_draw_device_close_path(uint64_t, uint64_t);
void fz_draw_device_concat_ctm(uint64_t, uint64_t, const float*);
void fz_draw_device_curve_to(uint64_t, uint64_t, float, float, float, float, float, float);
void fz_draw_device_enable_overprint(uint64_t, uint64_t, int32_t);
void fz_draw_device_enable_subpixel_text(uint64_t, uint64_t, int32_t);
void fz_draw_device_end_mask(uint64_t, uint64_t);
void fz_draw_device_end_pattern(uint64_t, uint64_t);
void fz_draw_device_end_text(uint64_t, uint64_t);
void fz_draw_device_line_to(uint64_t, uint64_t, float, float);
void fz_draw_device_move_to(uint64_t, uint64_t, float, float);
void fz_draw_device_pop_clip(uint64_t, uint64_t);
void fz_draw_device_restore(uint64_t, uint64_t);
void fz_draw_device_save(uint64_t, uint64_t);
void fz_draw_device_set_aa_level(uint64_t, uint64_t, int32_t);
void fz_draw_device_set_alpha(uint64_t, uint64_t, float);
void fz_draw_device_set_blend_mode(uint64_t, uint64_t, int32_t);
void fz_draw_device_set_ctm(uint64_t, uint64_t, const float*);
void fz_draw_device_set_dash(uint64_t, uint64_t, const float*, int32_t, float);
void fz_draw_device_set_fill_color(uint64_t, uint64_t, float, float, float, float);
void fz_draw_device_set_line_cap(uint64_t, uint64_t, int32_t);
void fz_draw_device_set_line_join(uint64_t, uint64_t, int32_t);
void fz_draw_device_set_line_width(uint64_t, uint64_t, float);
void fz_draw_device_set_miter_limit(uint64_t, uint64_t, float);
void fz_draw_device_set_overprint(uint64_t, uint64_t, int32_t);
void fz_draw_device_set_stroke_color(uint64_t, uint64_t, float, float, float, float);
void fz_draw_story(uint64_t, uint64_t, uint64_t, float, float, float, float, float, float);
void fz_drop_archive(uint64_t, uint64_t);
void fz_drop_band_writer(uint64_t, uint64_t);
void fz_drop_bitmap(uint64_t, uint64_t);
void fz_drop_buffer(uint64_t, uint64_t);
void fz_drop_buffered_writer(uint64_t, uint64_t);
void fz_drop_colorspace(uint64_t, uint64_t);
void fz_drop_compressed_buffer(uint64_t, uint64_t);
void fz_drop_conformance_validator(uint64_t, uint64_t);
void fz_drop_context(uint64_t);
void fz_drop_cookie(uint64_t, uint64_t);
void fz_drop_default_colorspaces(uint64_t, uint64_t);
void fz_drop_device(uint64_t, uint64_t);
void fz_drop_display_list(uint64_t, uint64_t);
void fz_drop_document(uint64_t, uint64_t);
void fz_drop_document_writer(uint64_t, uint64_t);
void fz_drop_draw_device(uint64_t, uint64_t);
void fz_drop_filter(uint64_t, uint64_t);
void fz_drop_font(uint64_t, uint64_t);
void fz_drop_glyph(uint64_t, uint64_t);
void fz_drop_heap(uint64_t, uint64_t);
void fz_drop_hyphenator(uint64_t, uint64_t);
void fz_drop_image(uint64_t, uint64_t);
void fz_drop_jbig2_globals(uint64_t, uint64_t);
void fz_drop_json(uint64_t, uint64_t);
void fz_drop_link(uint64_t, uint64_t);
void fz_drop_link_list(uint64_t, uint64_t);
void fz_drop_mapped_buffer(uint64_t, uint64_t);
void fz_drop_ocr_engine(uint64_t, uint64_t);
void fz_drop_ocr_result(uint64_t, uint64_t);
void fz_drop_outline(uint64_t, uint64_t);
void fz_drop_outline_iterator(uint64_t, uint64_t);
void fz_drop_output(uint64_t, uint64_t);
void fz_drop_page(uint64_t, uint64_t);
void fz_drop_page_aligned_buffer(uint64_t, uint64_t);
void fz_drop_path(uint64_t, uint64_t);
void fz_drop_pixmap(uint64_t, uint64_t);
void fz_drop_point_soa(uint64_t, uint64_t);
void fz_drop_pool(uint64_t, uint64_t);
void fz_drop_rect_soa(uint64_t, uint64_t);
void fz_drop_render_task(uint64_t, uint64_t);
void fz_drop_separations(uint64_t, uint64_t);
void fz_drop_shade(uint64_t, uint64_t);
void fz_drop_stext_page(uint64_t, uint64_t);
void fz_drop_story(uint64_t, uint64_t);
void fz_drop_stream(uint64_t, uint64_t);
void fz_drop_stroke_state(uint64_t, uint64_t);
void fz_drop_structure_tree(uint64_t, uint64_t);
void fz_drop_table(uint64_t, uint64_t);
void fz_drop_table_detector(uint64_t, uint64_t);
void fz_drop_text(uint64_t, uint64_t);
void fz_drop_tile_renderer(uint64_t, uint64_t);
void fz_drop_transition(uint64_t, uint64_t);
void fz_drop_validation_result(uint64_t, uint64_t);
void fz_drop_vectored_writer(uint64_t, uint64_t);
void fz_drop_xml(uint64_t, uint64_t);
void fz_dump_glyph_cache_stats(uint64_t, uint64_t);
void fz_empty_store(uint64_t);
void fz_enable_device_hints(uint64_t, uint64_t, int32_t);
void fz_enable_icc(uint64_t);
void fz_enable_memory_profiling(int32_t);
void fz_enable_stack_traces(int32_t);
void fz_end_group(uint64_t, uint64_t);
void fz_end_mask(uint64_t, uint64_t);
void fz_end_page(uint64_t, uint64_t);
void fz_end_tile(uint64_t, uint64_t);
void fz_fill_image(uint64_t, uint64_t, uint64_t, fz_matrix, float);
void fz_fill_image_mask(uint64_t, uint64_t, uint64_t, fz_matrix, uint64_t, const float*, float);
void fz_fill_path(uint64_t, uint64_t, uint64_t, int32_t, fz_matrix, uint64_t, const float*, float);
void fz_fill_text(uint64_t, uint64_t, uint64_t, fz_matrix, uint64_t, const float*, float);
void fz_flush_output(uint64_t, uint64_t);
void fz_flush_warnings(uint64_t);
void fz_font_name(uint64_t, uint64_t, uint64_t, int32_t);
void fz_format_output_path(uint64_t, char*, size_t, const char*, int32_t);
void fz_free_ocr_string(uint64_t, char*);
void fz_free_string(uint64_t, char*);
void fz_free_table_string(uint64_t, char*);
void fz_free_validation_string(uint64_t, char*);
void fz_gamma_pixmap(uint64_t, uint64_t, float);
void fz_glyph_bbox(uint64_t, uint64_t, float*);
void fz_glyph_cache_clear(uint64_t);
void fz_glyph_cache_insert(uint64_t, uint64_t, uint32_t, uint32_t, uint64_t);
void fz_glyph_cache_reset_stats(uint64_t);
void fz_glyph_cache_set_size(uint64_t, int32_t);
void fz_glyph_matrix(uint64_t, uint64_t, float*);
void fz_glyph_metrics(uint64_t, uint64_t, void*);
void fz_glyph_name(uint64_t, uint64_t, int32_t, uint64_t, int32_t);
void fz_glyph_origin(uint64_t, uint64_t, float*, float*);
void fz_glyph_subpixel(uint64_t, uint64_t, unsigned char*, unsigned char*);
void fz_gpu_drop_buffer(uint64_t);
void fz_gpu_drop_device(uint64_t);
void fz_gpu_drop_shader(uint64_t);
void fz_gpu_drop_texture(uint64_t);
void fz_grow_buffer(uint64_t, uint64_t);
void fz_heap_clear(uint64_t, uint64_t);
void fz_heap_reserve(uint64_t, uint64_t, size_t);
void fz_hyphenator_set_left_min(uint64_t, uint64_t, size_t);
void fz_hyphenator_set_right_min(uint64_t, uint64_t, size_t);
void fz_ignore_error(uint64_t);
void fz_ignore_text(uint64_t, uint64_t, uint64_t, fz_matrix);
void fz_int2_heap_sort(uint64_t, uint64_t);
void fz_intptr_heap_sort(uint64_t, uint64_t);
void fz_invert_pixmap(uint64_t, uint64_t);
void fz_layout_document(uint64_t, uint64_t, uint64_t, uint64_t, uint64_t);
void fz_lineto(uint64_t, uint64_t, float, float);
void fz_link_list_add(uint64_t, uint64_t, uint64_t);
void fz_link_list_clear(uint64_t, uint64_t);
void fz_locality_stats_reset(uint64_t);
void fz_log(uint64_t, const char*);
void fz_log_buffer_clear(uint64_t);
void fz_log_debug(uint64_t, const char*);
void fz_log_error(uint64_t, const char*);
void fz_log_fl(uint64_t, int32_t, const char*, int32_t, const char*);
void fz_log_include_location(uint64_t, int32_t);
void fz_log_include_timestamp(uint64_t, int32_t);
void fz_log_level(uint64_t, int32_t, const char*);
void fz_log_module(uint64_t, const char*, const char*);
void fz_log_set_warning_callback(uint64_t, uint64_t, void*);
void fz_log_trace(uint64_t, const char*);
void fz_log_warn(uint64_t, const char*);
void fz_mapped_buffer_seek(uint64_t, uint64_t, size_t);
void fz_md5_buffer(uint64_t, uint64_t, void*);
void fz_moveto(uint64_t, uint64_t, float, float);
void fz_new_icc_colorspace(uint64_t, int32_t);
void fz_ocr_engine_set_psm(uint64_t, uint64_t, uint64_t);
void fz_outline_iterator_update(uint64_t, uint64_t, const void*);
void fz_page_buffer_prefetch_read(uint64_t, uint64_t, uint64_t);
void fz_page_buffer_prefetch_write(uint64_t, uint64_t, uint64_t);
void fz_paragraph_break(uint64_t, uint64_t);
void fz_pixmap_resolution(uint64_t, uint64_t, int*, int*);
void fz_point_soa_push(uint64_t, uint64_t, float, float);
void fz_point_soa_transform(uint64_t, uint64_t, float, float, float, float, float, float);
void fz_pool_reset(uint64_t, uint64_t);
void fz_pool_set_block_size(uint64_t, uint64_t, size_t);
void fz_pool_shrink(uint64_t, uint64_t);
void fz_pop_clip(uint64_t, uint64_t);
void fz_prepare_t3_glyph(uint64_t, uint64_t, int32_t);
void fz_profiler_print_leak_report(uint64_t);
void fz_profiler_reset(void);
void fz_purge_glyph_cache(uint64_t);
void fz_quadto(uint64_t, uint64_t, float, float, float, float);
void fz_rect_soa_push(uint64_t, uint64_t, float, float, float, float);
void fz_rectto(uint64_t, uint64_t, float, float, float, float);
void fz_register_hyphenator(uint64_t, int32_t, uint64_t);
void fz_render_t3_glyph_direct(uint64_t, uint64_t, uint64_t, int32_t, uint64_t, uint64_t, uint64_t, uint64_t, uint64_t);
void fz_rendered_glyph_cache_insert(uint64_t, uint64_t, int32_t, const void*, uint8_t, uint8_t, int32_t, uint64_t, size_t);
void fz_report_error(uint64_t);
void fz_reset_cookie(uint64_t, uint64_t);
void fz_reset_output(uint64_t, uint64_t);
void fz_reset_story(uint64_t, uint64_t);
void fz_resize_buffer(uint64_t, uint64_t, size_t);
void fz_rethrow(uint64_t);
void fz_run_display_list(uint64_t, uint64_t, uint64_t, fz_matrix, fz_rect);
void fz_run_page(uint64_t, uint64_t, uint64_t, fz_matrix, uint64_t);
void fz_run_page_annots(uint64_t, uint64_t, uint64_t, fz_matrix, uint64_t);
void fz_run_page_contents(uint64_t, uint64_t, uint64_t, fz_matrix, uint64_t);
void fz_seek(uint64_t, uint64_t, int64_t, int32_t);
void fz_seek_output(uint64_t, uint64_t, int64_t, int32_t);
void fz_separation_equivalent(uint64_t, uint64_t, int32_t, float*);
void fz_set_aa_level(uint64_t, uint64_t);
void fz_set_all_separations_to_composite(uint64_t, uint64_t);
void fz_set_all_separations_to_spot(uint64_t, uint64_t);
void fz_set_default_cmyk(uint64_t, uint64_t, uint64_t);
void fz_set_default_gray(uint64_t, uint64_t, uint64_t);
void fz_set_default_output_intent(uint64_t, uint64_t, uint64_t);
void fz_set_default_rgb(uint64_t, uint64_t, uint64_t);
void fz_set_glyph_advance(uint64_t, uint64_t, float, float);
void fz_set_glyph_bbox(uint64_t, uint64_t, float, float, float, float);
void fz_set_glyph_cache_max_count(uint64_t, size_t);
void fz_set_glyph_cache_max_size(uint64_t, size_t);
void fz_set_glyph_cache_policy(uint64_t, int32_t);
void fz_set_glyph_color(uint64_t, uint64_t, int32_t);
void fz_set_glyph_hinting(uint64_t, uint64_t, int32_t);
void fz_set_glyph_matrix(uint64_t, uint64_t, const float*);
void fz_set_glyph_origin(uint64_t, uint64_t, float, float);
void fz_set_glyph_subpixel(uint64_t, uint64_t, uint8_t, uint8_t);
void fz_set_glyph_variation(uint64_t, uint64_t, int32_t, float);
void fz_set_link_rect(uint64_t, uint64_t, fz_rect);
void fz_set_log_buffer_size(uint64_t, size_t);
void fz_set_log_callback(uint64_t, uint64_t, void*);
void fz_set_log_file(uint64_t, const char*);
void fz_set_log_level(uint64_t, int32_t);
void fz_set_module_log_level(uint64_t, const char*, int32_t);
void fz_set_outline_color(uint64_t, uint64_t, float, float, float);
void fz_set_outline_down(uint64_t, uint64_t, uint64_t);
void fz_set_outline_flags(uint64_t, uint64_t, int32_t);
void fz_set_outline_is_open(uint64_t, uint64_t, int32_t);
void fz_set_outline_next(uint64_t, uint64_t, uint64_t);
void fz_set_outline_page(uint64_t, uint64_t, int32_t, int32_t);
void fz_set_outline_title(uint64_t, uint64_t, const char*);
void fz_set_outline_uri(uint64_t, uint64_t, const char*);
void fz_set_outline_xy(uint64_t, uint64_t, float, float);
void fz_set_pixmap_resolution(uint64_t, uint64_t, int32_t, int32_t);
void fz_set_pixmap_sample(uint64_t, uint64_t, int32_t, int32_t, int32_t, uint8_t);
void fz_set_pixmap_xres(uint64_t, uint64_t, int32_t);
void fz_set_pixmap_yres(uint64_t, uint64_t, int32_t);
void fz_set_separation_behavior(uint64_t, uint64_t, int32_t, int32_t);
void fz_set_separation_equivalent(uint64_t, uint64_t, int32_t, const float*);
void fz_set_text_language(uint64_t, uint64_t, uint64_t);
void fz_shade_bbox(uint64_t, uint64_t, float*);
void fz_shade_sample(uint64_t, uint64_t, float, float*);
void fz_shade_set_background(uint64_t, uint64_t, const float*);
void fz_shade_set_bbox(uint64_t, uint64_t, float, float, float, float);
void fz_show_glyph(uint64_t, uint64_t, uint64_t, fz_matrix, int32_t, int32_t, int32_t);
void fz_show_string(uint64_t, uint64_t, uint64_t, fz_matrix, uint64_t, int32_t);
void fz_shrink_store(uint64_t, uint64_t);
void fz_skip_space(uint64_t, uint64_t);
void fz_spin_loop_hint(void);
void fz_stext_block_bbox(uint64_t, uint64_t, int32_t, float*, float*, float*, float*);
void fz_stext_char_origin(uint64_t, uint64_t, int32_t, int32_t, int32_t, float*, float*);
void fz_stext_char_quad(uint64_t, uint64_t, int32_t, int32_t, int32_t, void*);
void fz_stext_line_bbox(uint64_t, uint64_t, int32_t, int32_t, float*, float*, float*, float*);
void fz_stext_page_mediabox(uint64_t, uint64_t, float*, float*, float*, float*);
void fz_store_clear(uint64_t);
void fz_store_debug(uint64_t);
void fz_store_drop(uint64_t, uint64_t);
void fz_store_reset_stats(uint64_t);
void fz_store_set_evictable(uint64_t, uint64_t, int32_t);
void fz_store_set_max_size(uint64_t, size_t);
void fz_store_set_policy(uint64_t, int32_t);
void fz_store_set_type_limit(uint64_t, int32_t, size_t);
void fz_story_positions(uint64_t, uint64_t, uint64_t, uint64_t);
void fz_story_set_em(uint64_t, float);
void fz_stroke_path(uint64_t, uint64_t, uint64_t, uint64_t, fz_matrix, uint64_t, const float*, float);
void fz_stroke_state_set_dash(uint64_t, uint64_t, float, const float*, int32_t);
void fz_stroke_state_set_end_cap(uint64_t, uint64_t, int32_t);
void fz_stroke_state_set_linejoin(uint64_t, uint64_t, int32_t);
void fz_stroke_state_set_linewidth(uint64_t, uint64_t, float);
void fz_stroke_state_set_miterlimit(uint64_t, uint64_t, float);
void fz_stroke_state_set_start_cap(uint64_t, uint64_t, int32_t);
void fz_stroke_text(uint64_t, uint64_t, uint64_t, uint64_t, fz_matrix, uint64_t, const float*, float);
void fz_subpixel_adjust(uint64_t, float*, float*, unsigned char*, unsigned char*, int32_t);
void fz_table_detector_clear(uint64_t, uint64_t);
void fz_table_hunt(uint64_t, uint64_t);
void fz_terminate_buffer(uint64_t, uint64_t);
void fz_tile_renderer_dimensions(uint64_t, uint64_t, uint32_t*, uint32_t*);
void fz_tile_renderer_grid(uint64_t, uint64_t, uint32_t*, uint32_t*);
void fz_tint_pixmap(uint64_t, uint64_t, int32_t, int32_t, int32_t);
void fz_transform_path(uint64_t, uint64_t, fz_matrix);
void fz_transition_set_direction(uint64_t, int32_t);
void fz_transition_set_duration(uint64_t, float);
void fz_transition_set_outwards(uint64_t, int32_t);
void fz_transition_set_vertical(uint64_t, int32_t);
void fz_tree_node_bbox(uint64_t, uint64_t, float*);
void fz_tree_node_set_actual_text(uint64_t, uint64_t, const char*);
void fz_tree_node_set_alt(uint64_t, uint64_t, const char*);
void fz_tree_node_set_id(uint64_t, uint64_t, uint64_t, const char*);
void fz_tree_node_set_lang(uint64_t, uint64_t, const char*);
void fz_tree_node_set_mcid(uint64_t, uint64_t, int32_t);
void fz_tree_node_set_page(uint64_t, uint64_t, int32_t, float, float, float, float);
void fz_tree_node_set_title(uint64_t, uint64_t, const char*);
void fz_trim_buffer(uint64_t, uint64_t);
void fz_truncate_output(uint64_t, uint64_t);
void fz_unread_byte(uint64_t, uint64_t);
void fz_validate_pdf2(uint64_t, uint64_t);
void fz_validate_pdfa(uint64_t, uint64_t);
void fz_validate_pdfx(uint64_t, uint64_t);
void fz_write_base64(uint64_t, uint64_t, const unsigned char*, size_t, int32_t);
void fz_write_base64_uri(uint64_t, uint64_t, const unsigned char*, size_t);
void fz_write_bits(uint64_t, uint64_t, uint32_t, int32_t);
void fz_write_bits_sync(uint64_t, uint64_t);
void fz_write_buffer(uint64_t, uint64_t, uint64_t);
void fz_write_byte(uint64_t, uint64_t, uint8_t);
void fz_write_char(uint64_t, uint64_t, uint64_t);
void fz_write_data(uint64_t, uint64_t, const void*, size_t);
void fz_write_document(uint64_t, uint64_t, uint64_t);
void fz_write_float_be(uint64_t, uint64_t, float);
void fz_write_float_le(uint64_t, uint64_t, float);
void fz_write_int16_be(uint64_t, uint64_t, int16_t);
void fz_write_int16_le(uint64_t, uint64_t, int16_t);
void fz_write_int32_be(uint64_t, uint64_t, int32_t);
void fz_write_int32_le(uint64_t, uint64_t, int32_t);
void fz_write_int64_be(uint64_t, uint64_t, int64_t);
void fz_write_int64_le(uint64_t, uint64_t, int64_t);
void fz_write_rune(uint64_t, uint64_t, int32_t);
void fz_write_string(uint64_t, uint64_t, const char*);
void fz_write_uint16_be(uint64_t, uint64_t, uint16_t);
void fz_write_uint16_le(uint64_t, uint64_t, uint16_t);
void fz_write_uint32_be(uint64_t, uint64_t, uint32_t);
void fz_write_uint32_le(uint64_t, uint64_t, uint32_t);
void fz_write_uint64_be(uint64_t, uint64_t, uint64_t);
void fz_write_uint64_le(uint64_t, uint64_t, uint64_t);
void* fz_default_stext_options(uint64_t, void*);
void* fz_parse_stext_options(uint64_t, void*, const char*);
void* fz_user_context(uint64_t);

    // ============================================================================
    // MICROPDF CONVENIENCE FUNCTIONS (120 functions)
    // ============================================================================

char* mp_extract_page_text(const char*, int32_t);
const char* mp_certificate_get_issuer(uint64_t);
const char* mp_certificate_get_subject(uint64_t);
float mp_frame_available_height(uint64_t);
float mp_frame_available_width(uint64_t);
float mp_html_options_get_content_height(uint64_t);
float mp_html_options_get_content_width(uint64_t);
float mp_html_options_get_page_height(uint64_t);
float mp_html_options_get_page_width(uint64_t);
int32_t mp_add_blank_page(uint64_t, uint64_t, float, float);
int32_t mp_add_watermark(uint64_t, uint64_t, uint64_t, uint64_t, float, float, float, float);
int32_t mp_copy_pages(const char*, const char*, const int*, int32_t);
int32_t mp_doc_template_set_margins(uint64_t, float, float, float, float);
int32_t mp_doc_template_set_page_size(uint64_t, float, float);
int32_t mp_draw_circle(uint64_t, uint64_t, float, float, float, float, float, float, float, int32_t);
int32_t mp_draw_line(uint64_t, uint64_t, float, float, float, float, float, float, float, float, float);
int32_t mp_draw_rectangle(uint64_t, uint64_t, float, float, float, float, float, float, float, float, int32_t);
int32_t mp_extract_text(const char*, void*);
int32_t mp_get_page_count(const char*);
int32_t mp_get_page_dimensions(const char*, int32_t, void*);
int32_t mp_get_pdf_info(const char*, void*);
int32_t mp_html_file_to_pdf(const char*, const char*, uint64_t);
int32_t mp_html_options_set_base_url(uint64_t, const char*);
int32_t mp_html_options_set_footer(uint64_t, const char*);
int32_t mp_html_options_set_header(uint64_t, const char*);
int32_t mp_html_options_set_javascript(uint64_t, int32_t);
int32_t mp_html_options_set_landscape(uint64_t, int32_t);
int32_t mp_html_options_set_margins(uint64_t, float, float, float, float);
int32_t mp_html_options_set_page_size(uint64_t, int32_t);
int32_t mp_html_options_set_page_size_custom(uint64_t, float, float);
int32_t mp_html_options_set_print_background(uint64_t, int32_t);
int32_t mp_html_options_set_scale(uint64_t, float);
int32_t mp_html_options_set_stylesheet(uint64_t, const char*);
int32_t mp_html_to_pdf(const char*, const char*, uint64_t);
int32_t mp_is_valid_pdf(const char*);
int32_t mp_linearize_pdf(uint64_t, uint64_t, uint64_t);
int32_t mp_merge_pdf_files(const const char*, int32_t, const char*);
int32_t mp_merge_pdfs(uint64_t, uint64_t, int32_t, uint64_t);
int32_t mp_optimize_pdf(uint64_t, uint64_t);
int32_t mp_overlay_pdf(uint64_t, uint64_t, uint64_t, uint64_t, float);
int32_t mp_paragraph_set_font_size(uint64_t, float);
int32_t mp_paragraph_set_leading(uint64_t, float);
int32_t mp_render_page_to_png(const char*, int32_t, float, void*);
int32_t mp_render_page_to_rgb(const char*, int32_t, float, void*);
int32_t mp_repair_damaged_pdf(const char*, const char*);
int32_t mp_restore_bookmarks(uint64_t, uint64_t, uint64_t);
int32_t mp_split_pdf(uint64_t, uint64_t, uint64_t);
int32_t mp_split_pdf_to_pages(const char*, const char*);
int32_t mp_stylesheet_add_style(uint64_t, uint64_t);
int32_t mp_toc_builder_add_heading(uint64_t, const char*, uint8_t, size_t);
int32_t mp_write_pdf(uint64_t, uint64_t, uint64_t);
size_t mp_story_len(uint64_t);
size_t mp_table_num_cols(uint64_t);
size_t mp_table_num_rows(uint64_t);
uint64_t mp_certificate_is_valid(uint64_t);
uint64_t mp_certificate_load_pem(const char*, const char*, const char*);
uint64_t mp_certificate_load_pkcs12(const char*, const char*);
uint64_t mp_decrypt_pdf(const char*, const char*, const char*);
uint64_t mp_doc_template_create(const char*);
uint64_t mp_encrypt_pdf(const char*, const char*, uint64_t);
uint64_t mp_encryption_options_new(void);
uint64_t mp_encryption_set_algorithm(uint64_t, uint64_t);
uint64_t mp_encryption_set_owner_password(uint64_t, const char*);
uint64_t mp_encryption_set_permissions(uint64_t, uint64_t);
uint64_t mp_encryption_set_user_password(uint64_t, const char*);
uint64_t mp_frame_create(const char*, float, float, float, float);
uint64_t mp_hr_create(void);
uint64_t mp_hr_set_thickness(uint64_t, float);
uint64_t mp_html_options_create(void);
uint64_t mp_image_create(const char*);
uint64_t mp_image_set_height(uint64_t, float);
uint64_t mp_image_set_width(uint64_t, float);
uint64_t mp_is_encrypted(const char*);
uint64_t mp_list_item_bullet(const char*);
uint64_t mp_list_item_numbered(size_t, const char*);
uint64_t mp_paragraph_create(const char*);
uint64_t mp_paragraph_style_create(const char*);
uint64_t mp_paragraph_style_set_alignment(uint64_t, int32_t);
uint64_t mp_paragraph_style_set_font_size(uint64_t, float);
uint64_t mp_paragraph_style_set_leading(uint64_t, float);
uint64_t mp_signature_count(const char*);
uint64_t mp_signature_create(const char*, const char*, uint64_t, const char*, uint64_t, float, float, float, float, const char*, const char*);
uint64_t mp_signature_create_invisible(const char*, const char*, uint64_t, const char*, const char*, const char*);
uint64_t mp_signature_verify(const char*, const char*, void*);
uint64_t mp_spacer_create(float);
uint64_t mp_story_create(void);
uint64_t mp_stylesheet_create(void);
uint64_t mp_table_create(size_t, size_t);
uint64_t mp_table_style_add_background(uint64_t, int32_t, int32_t, int32_t, int32_t, float, float, float);
uint64_t mp_table_style_add_grid(uint64_t, float, float, float, float);
uint64_t mp_table_style_create(void);
uint64_t mp_toc_add_entry(uint64_t, const char*, uint8_t, size_t);
uint64_t mp_toc_builder_create(void);
uint64_t mp_toc_create(void);
uint64_t mp_toc_set_title(uint64_t, const char*);
uint64_t mp_tsa_timestamp(const char*, const unsigned char*, size_t, const unsigned char*, size_t*);
void mp_certificate_drop(uint64_t);
void mp_doc_template_free(uint64_t);
void mp_encryption_options_drop(uint64_t);
void mp_frame_free(uint64_t);
void mp_free_bytes(unsigned char*, size_t);
void mp_free_extracted_text(void*);
void mp_free_pdf_info(void*);
void mp_free_rendered_page(void*);
void mp_free_string(char*);
void mp_free_timestamp(unsigned char*, size_t);
void mp_hr_free(uint64_t);
void mp_html_options_free(uint64_t);
void mp_image_free(uint64_t);
void mp_list_item_free(uint64_t);
void mp_paragraph_free(uint64_t);
void mp_paragraph_style_free(uint64_t);
void mp_signature_verify_result_free(void*);
void mp_spacer_free(uint64_t);
void mp_story_free(uint64_t);
void mp_stylesheet_free(uint64_t);
void mp_table_free(uint64_t);
void mp_table_style_free(uint64_t);
void mp_toc_builder_free(uint64_t);
void mp_toc_free(uint64_t);

    // ============================================================================
    // OFFICE DOCUMENT FUNCTIONS (30 functions)
    // ============================================================================

char* office_get_cell_string(uint64_t, uint64_t, int32_t, int32_t, int32_t);
char* office_get_creator(uint64_t, uint64_t);
char* office_get_sheet_name(uint64_t, uint64_t, int32_t);
char* office_get_slide_title(uint64_t, uint64_t, int32_t);
char* office_get_title(uint64_t, uint64_t);
char* office_type_extension(uint64_t, int32_t);
char* office_type_name(uint64_t, int32_t);
int32_t office_add_heading(uint64_t, uint64_t, const char*, int32_t);
int32_t office_add_paragraph(uint64_t, uint64_t, const char*);
int32_t office_add_sheet(uint64_t, uint64_t, const char*);
int32_t office_add_slide(uint64_t, uint64_t);
int32_t office_content_count(uint64_t, uint64_t);
int32_t office_get_page_size(uint64_t, uint64_t, float*, float*);
int32_t office_get_type(uint64_t, uint64_t);
int32_t office_page_count(uint64_t, uint64_t);
int32_t office_set_cell_number(uint64_t, uint64_t, int32_t, int32_t, int32_t, double);
int32_t office_set_cell_string(uint64_t, uint64_t, int32_t, int32_t, int32_t, const char*);
int32_t office_set_creator(uint64_t, uint64_t, const char*);
int32_t office_set_page_size(uint64_t, uint64_t, float, float);
int32_t office_set_slide_title(uint64_t, uint64_t, int32_t, const char*);
int32_t office_set_title(uint64_t, uint64_t, const char*);
int32_t office_sheet_count(uint64_t, uint64_t);
int32_t office_slide_count(uint64_t, uint64_t);
uint64_t office_new_document(uint64_t, int32_t);
uint64_t office_new_docx(uint64_t);
uint64_t office_new_pptx(uint64_t);
uint64_t office_new_xlsx(uint64_t);
uint64_t office_open_document(uint64_t, const char*);
void office_drop_document(uint64_t, uint64_t);
void office_free_string(char*);

    // ============================================================================
    // PDF FUNCTIONS (802 functions)
    // ============================================================================

char* pdf_3d_format_to_string(uint64_t, int32_t);
char* pdf_3d_get_view_name(uint64_t, uint64_t, int32_t);
char* pdf_3d_lighting_to_string(uint64_t, int32_t);
char* pdf_3d_render_mode_to_string(uint64_t, int32_t);
char* pdf_access_exec_menu_item_event(uint64_t, uint64_t, int32_t);
char* pdf_af_relationship_to_string(uint64_t, int32_t);
char* pdf_collection_view_to_string(uint64_t, int32_t);
char* pdf_format_write_options(uint64_t, char*, size_t, const void*);
char* pdf_get_interned_name(int32_t);
char* pdf_js_event_value(uint64_t);
char* pdf_js_get_console_log(uint64_t);
char* pdf_js_get_global(uint64_t, const char*);
char* pdf_js_get_last_error(uint64_t);
char* pdf_portfolio_get_mime_type(uint64_t, uint64_t, const char*);
char* pdf_portfolio_get_name(uint64_t, uint64_t, int32_t);
char* pdf_portfolio_schema_field_key(uint64_t, uint64_t, int32_t);
char* pdf_xref_entry_type_string(uint64_t, int32_t);
char* pdf_zugferd_af_relationship(uint64_t);
char* pdf_zugferd_mime_type(uint64_t);
char* pdf_zugferd_profile_to_string(uint64_t, int32_t);
char* pdf_zugferd_standard_filename(uint64_t, int32_t);
const char* pdf_clean_font_name(const char*);
const char* pdf_cmap_name(uint64_t, uint64_t);
const char* pdf_dn_c(uint64_t, uint64_t);
const char* pdf_dn_cn(uint64_t, uint64_t);
const char* pdf_dn_email(uint64_t, uint64_t);
const char* pdf_dn_o(uint64_t, uint64_t);
const char* pdf_dn_ou(uint64_t, uint64_t);
const char* pdf_font_name(uint64_t, uint64_t);
const char* pdf_layer_config_creator(uint64_t, uint64_t, int32_t);
const char* pdf_layer_config_name(uint64_t, uint64_t, int32_t);
const char* pdf_layer_config_ui_type_to_string(int32_t);
const char* pdf_layer_name(uint64_t, uint64_t, int32_t);
const char* pdf_lexbuf_get_string(uint64_t, uint64_t);
const char* pdf_parser_get_error(uint64_t, uint64_t);
const char* pdf_parser_get_string(uint64_t, uint64_t);
const char* pdf_signature_error_description(int32_t);
const char* pdf_signature_format_distinguished_name(uint64_t, uint64_t);
const char* pdf_signature_info(uint64_t, const char*, uint64_t, const char*, const char*, int64_t, int32_t);
const char* pdf_to_name(uint64_t, uint64_t);
const char* pdf_to_str_buf(uint64_t, uint64_t);
const char* pdf_to_string(uint64_t, uint64_t, size_t*);
const char* pdf_token_name(int32_t);
const unsigned char* pdf_3d_get_data(uint64_t, uint64_t, size_t*);
const unsigned char* pdf_lookup_substitute_font(uint64_t, int32_t, int32_t, int32_t, int32_t, int*);
const unsigned char* pdf_portfolio_get_file(uint64_t, uint64_t, const char*, size_t*);
const unsigned char* pdf_zugferd_xml(uint64_t, uint64_t, size_t*);
double pdf_name_table_hit_rate(void);
float pdf_annot_border_width(uint64_t, uint64_t);
float pdf_annot_opacity(uint64_t, uint64_t);
float pdf_field_border_width(uint64_t, uint64_t);
float pdf_field_font_size(uint64_t, uint64_t);
float pdf_font_ascent(uint64_t, uint64_t);
float pdf_font_cap_height(uint64_t, uint64_t);
float pdf_font_descent(uint64_t, uint64_t);
float pdf_font_italic_angle(uint64_t, uint64_t);
float pdf_font_missing_width(uint64_t, uint64_t);
float pdf_font_x_height(uint64_t, uint64_t);
float pdf_lexbuf_get_float(uint64_t, uint64_t);
float pdf_page_user_unit(uint64_t, uint64_t);
float pdf_parser_get_float(uint64_t, uint64_t);
float pdf_pattern_xstep(uint64_t, uint64_t);
float pdf_pattern_ystep(uint64_t, uint64_t);
float pdf_processor_get_line_width(uint64_t, uint64_t);
float pdf_rgb_to_gray(float, float, float);
float pdf_to_real(uint64_t, uint64_t);
float pdf_to_real_default(uint64_t, uint64_t, float);
float pdf_zugferd_version(uint64_t, uint64_t);
fz_rect pdf_annot_rect(uint64_t, uint64_t);
fz_rect pdf_field_rect(uint64_t, uint64_t);
int32_t pdf_3d_add_view(uint64_t, uint64_t, const char*);
int32_t pdf_3d_get_activation(uint64_t, uint64_t);
int32_t pdf_3d_get_deactivation(uint64_t, uint64_t);
int32_t pdf_3d_get_default_view(uint64_t, uint64_t);
int32_t pdf_3d_get_format(uint64_t, uint64_t);
int32_t pdf_3d_get_view_camera(uint64_t, uint64_t, int32_t, void*);
int32_t pdf_3d_set_activation(uint64_t, uint64_t, int32_t);
int32_t pdf_3d_set_deactivation(uint64_t, uint64_t, int32_t);
int32_t pdf_3d_set_default_view(uint64_t, uint64_t, int32_t);
int32_t pdf_3d_set_interactive(uint64_t, uint64_t, int32_t);
int32_t pdf_3d_set_navigation(uint64_t, uint64_t, int32_t);
int32_t pdf_3d_set_prc_data(uint64_t, uint64_t, const unsigned char*, size_t);
int32_t pdf_3d_set_toolbar(uint64_t, uint64_t, int32_t);
int32_t pdf_3d_set_u3d_data(uint64_t, uint64_t, const unsigned char*, size_t);
int32_t pdf_3d_set_view_background(uint64_t, uint64_t, int32_t, float, float, float, float);
int32_t pdf_3d_set_view_camera(uint64_t, uint64_t, int32_t, const void*);
int32_t pdf_3d_set_view_lighting(uint64_t, uint64_t, int32_t, int32_t);
int32_t pdf_3d_set_view_render_mode(uint64_t, uint64_t, int32_t, int32_t);
int32_t pdf_3d_view_count(uint64_t, uint64_t);
int32_t pdf_access_launch_url_event(uint64_t, uint64_t, int32_t, char*, int*);
int32_t pdf_add_field_choice(uint64_t, uint64_t, uint64_t, uint64_t);
int32_t pdf_add_layer(uint64_t, uint64_t, const char*, int32_t);
int32_t pdf_add_layer_config(uint64_t, uint64_t, const char*, const char*);
int32_t pdf_add_layer_config_ui(uint64_t, uint64_t, const char*, int32_t, int32_t, int32_t, int32_t);
int32_t pdf_add_signature(uint64_t, uint64_t, const char*, int64_t);
int32_t pdf_alert_get_button_pressed(const void*);
int32_t pdf_annot_author(uint64_t, uint64_t, uint64_t, int32_t);
int32_t pdf_annot_contents(uint64_t, uint64_t, uint64_t, int32_t);
int32_t pdf_annot_has_dirty(uint64_t, uint64_t);
int32_t pdf_annot_has_popup(uint64_t, uint64_t);
int32_t pdf_annot_is_valid(uint64_t, uint64_t);
int32_t pdf_annot_line(uint64_t, uint64_t, fz_point, fz_point);
int32_t pdf_annot_type(uint64_t, uint64_t);
int32_t pdf_apply_all_redactions(uint64_t, uint64_t, const void*);
int32_t pdf_apply_redaction(uint64_t, uint64_t, const void*);
int32_t pdf_apply_redactions(uint64_t, uint64_t);
int32_t pdf_array_len(uint64_t, uint64_t);
int32_t pdf_cache_object(uint64_t, uint64_t, int32_t);
int32_t pdf_can_be_saved_incrementally(uint64_t, uint64_t);
int32_t pdf_check_certificate(uint64_t, uint64_t, uint64_t, uint64_t);
int32_t pdf_check_digest(uint64_t, uint64_t, uint64_t, uint64_t);
int32_t pdf_cmap_codespace_len(uint64_t, uint64_t);
int32_t pdf_cmap_has_usecmap(uint64_t, uint64_t);
int32_t pdf_cmap_mrange_count(uint64_t, uint64_t);
int32_t pdf_cmap_range_count(uint64_t, uint64_t);
int32_t pdf_cmap_wmode(uint64_t, uint64_t);
int32_t pdf_cmap_xrange_count(uint64_t, uint64_t);
int32_t pdf_count_images(uint64_t, uint64_t);
int32_t pdf_count_layer_config_ui(uint64_t, uint64_t);
int32_t pdf_count_layer_configs(uint64_t, uint64_t);
int32_t pdf_count_layers(uint64_t, uint64_t);
int32_t pdf_count_objects(uint64_t, uint64_t);
int32_t pdf_count_output_intents(uint64_t, uint64_t);
int32_t pdf_count_pages(uint64_t, uint64_t);
int32_t pdf_count_pending_events(uint64_t, uint64_t);
int32_t pdf_count_redact_regions(uint64_t, uint64_t);
int32_t pdf_count_signatures(uint64_t, uint64_t);
int32_t pdf_create_object(uint64_t, uint64_t);
int32_t pdf_decode_cmap(uint64_t, const unsigned char*, const unsigned char*, uint32_t*);
int32_t pdf_delete_field(uint64_t, uint64_t, uint64_t);
int32_t pdf_dict_len(uint64_t, uint64_t);
int32_t pdf_field_alignment(uint64_t, uint64_t);
int32_t pdf_field_choice_count(uint64_t, uint64_t);
int32_t pdf_field_choice_label(uint64_t, uint64_t, int32_t, uint64_t, int32_t);
int32_t pdf_field_choice_value(uint64_t, uint64_t, int32_t, uint64_t, int32_t);
int32_t pdf_field_default_value(uint64_t, uint64_t, char*, int32_t);
int32_t pdf_field_is_checked(uint64_t, uint64_t);
int32_t pdf_field_is_combo(uint64_t, uint64_t);
int32_t pdf_field_is_edit(uint64_t, uint64_t);
int32_t pdf_field_is_multiline(uint64_t, uint64_t);
int32_t pdf_field_is_multiselect(uint64_t, uint64_t);
int32_t pdf_field_is_password(uint64_t, uint64_t);
int32_t pdf_field_is_read_only(uint64_t, uint64_t);
int32_t pdf_field_is_required(uint64_t, uint64_t);
int32_t pdf_field_is_signed(uint64_t, uint64_t);
int32_t pdf_field_is_valid(uint64_t, uint64_t);
int32_t pdf_field_max_len(uint64_t, uint64_t);
int32_t pdf_field_name(uint64_t, uint64_t, uint64_t, int32_t);
int32_t pdf_field_selected_index(uint64_t, uint64_t);
int32_t pdf_field_text_format(uint64_t, uint64_t);
int32_t pdf_field_type(uint64_t, uint64_t);
int32_t pdf_field_value(uint64_t, uint64_t, uint64_t, int32_t);
int32_t pdf_font_cid_to_gid(uint64_t, uint64_t, int32_t);
int32_t pdf_font_cid_to_unicode(uint64_t, uint64_t, int32_t);
int32_t pdf_font_flags(uint64_t, uint64_t);
int32_t pdf_font_is_embedded(uint64_t, uint64_t);
int32_t pdf_font_wmode(uint64_t, uint64_t);
int32_t pdf_font_writing_supported(uint64_t, uint64_t);
int32_t pdf_form_field_count(uint64_t, uint64_t);
int32_t pdf_get_current_layer_config(uint64_t, uint64_t);
int32_t pdf_get_pending_event_type(uint64_t, uint64_t, int32_t);
int32_t pdf_get_xref_entry(uint64_t, uint64_t, int32_t, void*);
int32_t pdf_guess_colorspace_components(uint64_t, uint64_t);
int32_t pdf_has_unsaved_sigs(uint64_t, uint64_t);
int32_t pdf_intern_name(const char*);
int32_t pdf_is_arena_handle(uint64_t, uint64_t);
int32_t pdf_is_array(uint64_t, uint64_t);
int32_t pdf_is_bool(uint64_t, uint64_t);
int32_t pdf_is_dict(uint64_t, uint64_t);
int32_t pdf_is_indirect(uint64_t, uint64_t);
int32_t pdf_is_int(uint64_t, uint64_t);
int32_t pdf_is_jpx_image(uint64_t, uint64_t);
int32_t pdf_is_local_object(uint64_t, uint64_t, int32_t);
int32_t pdf_is_name(uint64_t, uint64_t);
int32_t pdf_is_null(uint64_t, uint64_t);
int32_t pdf_is_number(uint64_t, uint64_t);
int32_t pdf_is_ocg_hidden(uint64_t, uint64_t, uint64_t, const char*, uint64_t);
int32_t pdf_is_portfolio(uint64_t, uint64_t);
int32_t pdf_is_real(uint64_t, uint64_t);
int32_t pdf_is_stream(uint64_t, uint64_t);
int32_t pdf_is_string(uint64_t, uint64_t);
int32_t pdf_is_tint_colorspace(uint64_t, uint64_t);
int32_t pdf_is_zugferd(uint64_t, uint64_t);
int32_t pdf_js_event_result(uint64_t);
int32_t pdf_js_event_result_keystroke(uint64_t, void*);
int32_t pdf_js_event_result_validate(uint64_t, char*);
int32_t pdf_js_is_enabled(uint64_t);
int32_t pdf_js_supported(uint64_t, uint64_t);
int32_t pdf_layer_config_ui_type_from_string(const char*);
int32_t pdf_layer_has_unsaved_changes(uint64_t, uint64_t);
int32_t pdf_layer_is_enabled(uint64_t, uint64_t, int32_t);
int32_t pdf_lex(uint64_t, uint64_t);
int32_t pdf_lex_no_string(uint64_t, uint64_t);
int32_t pdf_lookup_cmap(uint64_t, uint32_t);
int32_t pdf_lookup_cmap_full(uint64_t, uint32_t, int*);
int32_t pdf_lookup_name(const char*);
int32_t pdf_lookup_named_dest(uint64_t, uint64_t, const char*);
int32_t pdf_lookup_page_number(uint64_t, uint64_t, uint64_t);
int32_t pdf_mark_obj(uint64_t, uint64_t);
int32_t pdf_mark_xref(uint64_t, uint64_t, int32_t);
int32_t pdf_name_eq(uint64_t, uint64_t, uint64_t);
int32_t pdf_name_eq_str(int32_t, const char*);
int32_t pdf_name_index_eq(int32_t, int32_t);
int32_t pdf_name_table_count(void);
int32_t pdf_obj_is_dirty(uint64_t, uint64_t);
int32_t pdf_obj_is_resolved(uint64_t, uint64_t, uint64_t);
int32_t pdf_obj_marked(uint64_t, uint64_t);
int32_t pdf_obj_parent_num(uint64_t, uint64_t);
int32_t pdf_obj_refs(uint64_t, uint64_t);
int32_t pdf_objcmp(uint64_t, uint64_t, uint64_t);
int32_t pdf_object_exists(uint64_t, uint64_t, int32_t);
int32_t pdf_page_has_transparency(uint64_t, uint64_t);
int32_t pdf_page_rotation(uint64_t, uint64_t);
int32_t pdf_parsed_array_len(uint64_t, uint64_t);
int32_t pdf_parsed_dict_len(uint64_t, uint64_t);
int32_t pdf_parsed_obj_type(uint64_t, uint64_t);
int32_t pdf_parser_get_token(uint64_t, uint64_t);
int32_t pdf_parser_has_error(uint64_t, uint64_t);
int32_t pdf_pattern_is_mask(uint64_t, uint64_t);
int32_t pdf_portfolio_add_file(uint64_t, uint64_t, const char*, const unsigned char*, size_t, const char*);
int32_t pdf_portfolio_add_schema_field(uint64_t, uint64_t, const char*, const char*, uint64_t);
int32_t pdf_portfolio_count(uint64_t, uint64_t);
int32_t pdf_portfolio_get_view(uint64_t, uint64_t);
int32_t pdf_portfolio_remove_file(uint64_t, uint64_t, const char*);
int32_t pdf_portfolio_schema_field_count(uint64_t, uint64_t);
int32_t pdf_portfolio_set_description(uint64_t, uint64_t, const char*, const char*);
int32_t pdf_portfolio_set_initial_document(uint64_t, uint64_t, const char*);
int32_t pdf_portfolio_set_sort(uint64_t, uint64_t, const char*, int32_t);
int32_t pdf_portfolio_set_view(uint64_t, uint64_t, int32_t);
int32_t pdf_processor_get_gstate_depth(uint64_t, uint64_t);
int32_t pdf_processor_get_operator_count(uint64_t, uint64_t);
int32_t pdf_processor_get_type(uint64_t, uint64_t);
int32_t pdf_processor_in_text(uint64_t, uint64_t);
int32_t pdf_recolor_options_is_valid(const void*);
int32_t pdf_redact_document(uint64_t, uint64_t, const void*);
int32_t pdf_redact_page(uint64_t, uint64_t, uint64_t, void*);
int32_t pdf_redact_page_annotations(uint64_t, uint64_t, uint64_t, const void*);
int32_t pdf_remove_field_choice(uint64_t, uint64_t, int32_t);
int32_t pdf_set_field_checked(uint64_t, uint64_t, int32_t);
int32_t pdf_set_field_default_value(uint64_t, uint64_t, const char*);
int32_t pdf_set_field_selected_index(uint64_t, uint64_t, int32_t);
int32_t pdf_set_field_value(uint64_t, uint64_t, uint64_t);
int32_t pdf_set_trailer(uint64_t, uint64_t, uint64_t);
int32_t pdf_set_version(uint64_t, uint64_t, int32_t);
int32_t pdf_signature_byte_range(uint64_t, uint64_t, uint64_t, void*);
int32_t pdf_signature_incremental_change_since_signing(uint64_t, uint64_t, uint64_t);
int32_t pdf_signature_is_signed(uint64_t, uint64_t, uint64_t);
int32_t pdf_std_name_filter(void);
int32_t pdf_std_name_font(void);
int32_t pdf_std_name_image(void);
int32_t pdf_std_name_length(void);
int32_t pdf_std_name_subtype(void);
int32_t pdf_std_name_type(void);
int32_t pdf_to_bool(uint64_t, uint64_t);
int32_t pdf_to_bool_default(uint64_t, uint64_t, int32_t);
int32_t pdf_to_gen(uint64_t, uint64_t);
int32_t pdf_to_int(uint64_t, uint64_t);
int32_t pdf_to_int_default(uint64_t, uint64_t, int32_t);
int32_t pdf_to_num(uint64_t, uint64_t);
int32_t pdf_update_annot(uint64_t, uint64_t);
int32_t pdf_update_object(uint64_t, uint64_t, int32_t, uint64_t);
int32_t pdf_update_stream(uint64_t, uint64_t, int32_t, uint64_t, int32_t);
int32_t pdf_validate_form(uint64_t, uint64_t);
int32_t pdf_version(uint64_t, uint64_t);
int32_t pdf_xobject_isolated(uint64_t, uint64_t);
int32_t pdf_xobject_knockout(uint64_t, uint64_t);
int32_t pdf_xobject_transparency(uint64_t, uint64_t);
int32_t pdf_xref_add_subsection(uint64_t, uint64_t, int32_t, int32_t);
int32_t pdf_xref_len(uint64_t, uint64_t);
int32_t pdf_xref_set_end_offset(uint64_t, uint64_t, int64_t);
int32_t pdf_xref_set_entry(uint64_t, uint64_t, int32_t, int32_t, uint16_t, int64_t);
int32_t pdf_zugferd_embed(uint64_t, uint64_t, const unsigned char*, size_t, const void*);
int32_t pdf_zugferd_error_count(uint64_t, uint64_t);
int32_t pdf_zugferd_profile(uint64_t, uint64_t, float*);
int32_t pdf_zugferd_set_xml(uint64_t, uint64_t, const unsigned char*, size_t);
int32_t pdf_zugferd_validate(uint64_t, uint64_t);
int64_t pdf_lexbuf_get_int(uint64_t, uint64_t);
int64_t pdf_parser_get_int(uint64_t, uint64_t);
int64_t pdf_portfolio_get_file_size(uint64_t, uint64_t, const char*);
int64_t pdf_to_int64(uint64_t, uint64_t);
int64_t pdf_xref_end_offset(uint64_t, uint64_t);
size_t pdf_cmap_size(uint64_t, uint64_t);
size_t pdf_function_size(uint64_t, uint64_t);
size_t pdf_lexbuf_get_len(uint64_t, uint64_t);
size_t pdf_object_arena_count(uint64_t);
size_t pdf_parser_get_pos(uint64_t, uint64_t);
size_t pdf_pkcs7_signer_max_digest_size(uint64_t, uint64_t);
size_t pdf_signature_contents(uint64_t, uint64_t, uint64_t, char*);
size_t pdf_to_str_len(uint64_t, uint64_t);
ssize_t pdf_lexbuf_grow(uint64_t, uint64_t);
uint32_t pdf_annot_flags(uint64_t, uint64_t);
uint32_t pdf_field_flags(uint64_t, uint64_t);
uint32_t pdf_new_object_arena(uint64_t);
uint32_t pdf_new_object_arena_with_size(uint64_t, size_t);
uint64_t pdf_add_cid_font(uint64_t, uint64_t, uint64_t);
uint64_t pdf_add_cjk_font(uint64_t, uint64_t, uint64_t, int32_t, int32_t, int32_t);
uint64_t pdf_add_colorspace(uint64_t, uint64_t, uint64_t);
uint64_t pdf_add_image(uint64_t, uint64_t, uint64_t);
uint64_t pdf_add_simple_font(uint64_t, uint64_t, uint64_t, int32_t);
uint64_t pdf_add_substitute_font(uint64_t, uint64_t, uint64_t);
uint64_t pdf_analyze_images(uint64_t, uint64_t);
uint64_t pdf_arena_new_array(uint64_t, uint32_t, size_t);
uint64_t pdf_arena_new_bool(uint64_t, uint32_t, int32_t);
uint64_t pdf_arena_new_dict(uint64_t, uint32_t, size_t);
uint64_t pdf_arena_new_indirect(uint64_t, uint32_t, int32_t, int32_t);
uint64_t pdf_arena_new_int(uint64_t, uint32_t, int64_t);
uint64_t pdf_arena_new_name(uint64_t, uint32_t, uint64_t);
uint64_t pdf_arena_new_null(uint64_t, uint32_t);
uint64_t pdf_arena_new_real(uint64_t, uint32_t, float);
uint64_t pdf_arena_new_string(uint64_t, uint32_t, const unsigned char*, size_t);
uint64_t pdf_array_get(uint64_t, uint64_t, int32_t);
uint64_t pdf_bound_page(uint64_t, uint64_t, int32_t);
uint64_t pdf_clone_annot(uint64_t, uint64_t);
uint64_t pdf_clone_field(uint64_t, uint64_t);
uint64_t pdf_copy_array(uint64_t, uint64_t, uint64_t);
uint64_t pdf_copy_dict(uint64_t, uint64_t, uint64_t);
uint64_t pdf_create_annot(uint64_t, uint64_t, int32_t);
uint64_t pdf_create_checkbox(uint64_t, uint64_t, uint64_t, float, float, float, float, int32_t);
uint64_t pdf_create_combo_box(uint64_t, uint64_t, uint64_t, float, float, float, float);
uint64_t pdf_create_push_button(uint64_t, uint64_t, uint64_t, float, float, float, float, uint64_t);
uint64_t pdf_create_redact_annot(uint64_t, uint64_t, float, float, float, float);
uint64_t pdf_create_signature_field(uint64_t, uint64_t, uint64_t, float, float, float, float);
uint64_t pdf_create_text_field(uint64_t, uint64_t, uint64_t, float, float, float, float, int32_t);
uint64_t pdf_deep_copy_obj(uint64_t, uint64_t, uint64_t);
uint64_t pdf_default_clean_options(void);
uint64_t pdf_default_image_rewriter_options(void);
uint64_t pdf_default_redact_options(void);
uint64_t pdf_default_write_options(void);
uint64_t pdf_dict_get(uint64_t, uint64_t, uint64_t);
uint64_t pdf_dict_get_key(uint64_t, uint64_t, int32_t);
uint64_t pdf_dict_get_val(uint64_t, uint64_t, int32_t);
uint64_t pdf_dict_gets(uint64_t, uint64_t, const char*);
uint64_t pdf_document_output_intent(uint64_t, uint64_t);
uint64_t pdf_ebook_image_rewriter_options(void);
uint64_t pdf_find_colorspace_resource(uint64_t, uint64_t, uint64_t, void*);
uint64_t pdf_find_font_resource(uint64_t, uint64_t, int32_t, int32_t, uint64_t, void*);
uint64_t pdf_first_annot(uint64_t, uint64_t);
uint64_t pdf_first_widget(uint64_t, uint64_t);
uint64_t pdf_form(uint64_t, uint64_t);
uint64_t pdf_get_cached_object(uint64_t, uint64_t, int32_t);
uint64_t pdf_get_js(uint64_t, uint64_t);
uint64_t pdf_get_redact_stats(uint64_t, uint64_t);
uint64_t pdf_get_signature(uint64_t, uint64_t, int32_t);
uint64_t pdf_get_stream_buffer(uint64_t, uint64_t, int32_t);
uint64_t pdf_get_total_image_size(uint64_t, uint64_t);
uint64_t pdf_insert_colorspace_resource(uint64_t, uint64_t, const void*, uint64_t);
uint64_t pdf_insert_font_resource(uint64_t, uint64_t, const void*, uint64_t);
uint64_t pdf_keep_annot(uint64_t, uint64_t);
uint64_t pdf_keep_cmap(uint64_t, uint64_t);
uint64_t pdf_keep_font(uint64_t, uint64_t);
uint64_t pdf_keep_form(uint64_t, uint64_t);
uint64_t pdf_keep_function(uint64_t, uint64_t);
uint64_t pdf_keep_obj(uint64_t, uint64_t);
uint64_t pdf_keep_page(uint64_t, uint64_t);
uint64_t pdf_keep_pattern(uint64_t, uint64_t);
uint64_t pdf_keep_processor(uint64_t, uint64_t);
uint64_t pdf_lexbuf_init(uint64_t, int32_t);
uint64_t pdf_load_builtin_cmap(uint64_t, const char*);
uint64_t pdf_load_cmap(uint64_t, uint64_t);
uint64_t pdf_load_colorspace(uint64_t, uint64_t);
uint64_t pdf_load_default_colorspaces(uint64_t, uint64_t, uint64_t);
uint64_t pdf_load_embedded_cmap(uint64_t, uint64_t, uint64_t);
uint64_t pdf_load_font(uint64_t, uint64_t, uint64_t, uint64_t);
uint64_t pdf_load_function(uint64_t, uint64_t, int32_t, int32_t);
uint64_t pdf_load_hail_mary_font(uint64_t, uint64_t);
uint64_t pdf_load_image(uint64_t, uint64_t, uint64_t);
uint64_t pdf_load_inline_image(uint64_t, uint64_t, uint64_t, uint64_t, uint64_t);
uint64_t pdf_load_links(uint64_t, uint64_t);
uint64_t pdf_load_object(uint64_t, uint64_t, int32_t, int32_t);
uint64_t pdf_load_page(uint64_t, uint64_t, int32_t);
uint64_t pdf_load_pattern(uint64_t, uint64_t, uint64_t);
uint64_t pdf_load_shading(uint64_t, uint64_t, uint64_t);
uint64_t pdf_load_system_cmap(uint64_t, const char*);
uint64_t pdf_load_type3_font(uint64_t, uint64_t, uint64_t, uint64_t);
uint64_t pdf_lookup_field(uint64_t, uint64_t, uint64_t);
uint64_t pdf_lookup_hmtx(uint64_t, uint64_t, int32_t);
uint64_t pdf_lookup_page_obj(uint64_t, uint64_t, int32_t);
uint64_t pdf_lookup_resource(uint64_t, uint64_t, uint64_t, const char*);
uint64_t pdf_lookup_vmtx(uint64_t, uint64_t, int32_t);
uint64_t pdf_max_compression_image_rewriter_options(void);
uint64_t pdf_name_table_hits(void);
uint64_t pdf_name_table_lookups(void);
uint64_t pdf_new_3d_annotation(uint64_t);
uint64_t pdf_new_array(uint64_t, uint64_t, int32_t);
uint64_t pdf_new_bool(uint64_t, int32_t);
uint64_t pdf_new_buffer_processor(uint64_t, uint64_t, int32_t, int32_t);
uint64_t pdf_new_cmap(uint64_t);
uint64_t pdf_new_color_filter(uint64_t, uint64_t, uint64_t, int32_t, float, float, float, float, float, float);
uint64_t pdf_new_date(uint64_t, uint64_t, int32_t, int32_t, int32_t, int32_t, int32_t, int32_t);
uint64_t pdf_new_dict(uint64_t, uint64_t, int32_t);
uint64_t pdf_new_event_handler(uint64_t, uint64_t);
uint64_t pdf_new_font_desc(uint64_t);
uint64_t pdf_new_identity_cmap(uint64_t, int32_t, int32_t);
uint64_t pdf_new_indirect(uint64_t, uint64_t, int32_t, int32_t);
uint64_t pdf_new_int(uint64_t, int64_t);
uint64_t pdf_new_matrix(uint64_t, uint64_t, float, float, float, float, float, float);
uint64_t pdf_new_name(uint64_t, const char*);
uint64_t pdf_new_null(uint64_t);
uint64_t pdf_new_output_processor(uint64_t, uint64_t, int32_t, int32_t);
uint64_t pdf_new_pixmap_from_page_contents_with_separations_and_usage(uint64_t, uint64_t, uint64_t, uint64_t, uint64_t, int32_t, const char*, int32_t);
uint64_t pdf_new_pixmap_from_page_contents_with_usage(uint64_t, uint64_t, uint64_t, uint64_t, int32_t, const char*, int32_t);
uint64_t pdf_new_pixmap_from_page_with_separations_and_usage(uint64_t, uint64_t, uint64_t, uint64_t, uint64_t, int32_t, const char*, int32_t);
uint64_t pdf_new_pixmap_from_page_with_usage(uint64_t, uint64_t, uint64_t, uint64_t, int32_t, const char*, int32_t);
uint64_t pdf_new_point(uint64_t, uint64_t, float, float);
uint64_t pdf_new_portfolio(uint64_t, uint64_t);
uint64_t pdf_new_processor(uint64_t, int32_t);
uint64_t pdf_new_real(uint64_t, float);
uint64_t pdf_new_rect(uint64_t, uint64_t, float, float, float, float);
uint64_t pdf_new_redact_context(uint64_t, uint64_t, uint64_t);
uint64_t pdf_new_resource_stack(uint64_t, uint64_t);
uint64_t pdf_new_run_processor(uint64_t, uint64_t, uint64_t, float, float, float, float, float, float, int32_t, const char*);
uint64_t pdf_new_sanitize_filter(uint64_t, uint64_t, uint64_t, int32_t, float, float, float, float, float, float);
uint64_t pdf_new_shade_recolor_context(uint64_t, uint64_t, uint64_t);
uint64_t pdf_new_string(uint64_t, const char*, size_t);
uint64_t pdf_new_text_string(uint64_t, const char*);
uint64_t pdf_new_vectorize_filter(uint64_t, uint64_t, uint64_t, int32_t, float, float, float, float, float, float);
uint64_t pdf_new_xobject(uint64_t, uint64_t, const float*, const float*, uint64_t, uint64_t);
uint64_t pdf_new_xref(uint64_t, uint64_t);
uint64_t pdf_new_zugferd_context(uint64_t, uint64_t);
uint64_t pdf_next_annot(uint64_t, uint64_t);
uint64_t pdf_next_widget(uint64_t, uint64_t);
uint64_t pdf_object_arena_stats(uint64_t, uint32_t);
uint64_t pdf_ocr_redact_options(void);
uint64_t pdf_page_contents(uint64_t, uint64_t);
uint64_t pdf_page_group(uint64_t, uint64_t);
uint64_t pdf_page_obj(uint64_t, uint64_t);
uint64_t pdf_page_resources(uint64_t, uint64_t);
uint64_t pdf_page_separations(uint64_t, uint64_t);
uint64_t pdf_parse_array(uint64_t, uint64_t, uint64_t);
uint64_t pdf_parse_dict(uint64_t, uint64_t, uint64_t);
uint64_t pdf_parse_ind_obj(uint64_t, uint64_t, uint64_t, int*, int*, int64_t*, int*);
uint64_t pdf_parse_stm_obj(uint64_t, uint64_t, uint64_t);
uint64_t pdf_parser_new(uint64_t, const unsigned char*, size_t);
uint64_t pdf_pkcs7_keep_signer(uint64_t, uint64_t);
uint64_t pdf_pkcs7_signer_get_name(uint64_t, uint64_t);
uint64_t pdf_pkcs7_signer_new(uint64_t, const char*);
uint64_t pdf_pkcs7_verifier_new(uint64_t);
uint64_t pdf_pop_resource_stack(uint64_t, uint64_t);
uint64_t pdf_print_image_rewriter_options(void);
uint64_t pdf_processor_pop_resources(uint64_t, uint64_t);
uint64_t pdf_push_resource_stack(uint64_t, uint64_t, uint64_t);
uint64_t pdf_read_ocg(uint64_t, uint64_t);
uint64_t pdf_recolor_document(uint64_t, uint64_t, const void*);
uint64_t pdf_recolor_options_cmyk(void);
uint64_t pdf_recolor_options_gray(void);
uint64_t pdf_recolor_options_new(int32_t);
uint64_t pdf_recolor_options_rgb(void);
uint64_t pdf_recolor_pages(uint64_t, uint64_t, int32_t, int32_t, const void*);
uint64_t pdf_recolor_shade(uint64_t, uint64_t, uint64_t);
uint64_t pdf_resolve_indirect(uint64_t, uint64_t, uint64_t);
uint64_t pdf_rewrite_images_with_stats(uint64_t, uint64_t, void*);
uint64_t pdf_secure_redact_options(void);
uint64_t pdf_signature_get_signatory(uint64_t, uint64_t, uint64_t, uint64_t);
uint64_t pdf_trailer(uint64_t, uint64_t);
uint64_t pdf_update_default_colorspaces(uint64_t, uint64_t, uint64_t);
uint64_t pdf_web_image_rewriter_options(void);
uint64_t pdf_xobject_colorspace(uint64_t, uint64_t);
uint64_t pdf_xobject_resources(uint64_t, uint64_t);
uint64_t pdf_zugferd_default_embed_params(void);
void pdf_3d_free_string(char*);
void pdf_add_codespace(uint64_t, uint64_t, uint32_t, uint32_t, size_t);
void pdf_add_hmtx(uint64_t, uint64_t, int32_t, int32_t, int32_t);
void pdf_add_redact_annot_quad(uint64_t, uint64_t, const float*, uint64_t);
void pdf_add_redact_region(uint64_t, uint64_t, float, float, float, float);
void pdf_add_redact_region_with_color(uint64_t, uint64_t, float, float, float, float, float, float, float);
void pdf_add_vmtx(uint64_t, uint64_t, int32_t, int32_t, int32_t, int32_t, int32_t);
void pdf_alert_set_button_group(void*, int32_t);
void pdf_alert_set_button_pressed(void*, int32_t);
void pdf_alert_set_icon(void*, int32_t);
void pdf_alert_set_message(void*, const char*);
void pdf_alert_set_title(void*, const char*);
void pdf_annot_clear_dirty(uint64_t, uint64_t);
void pdf_annot_color(uint64_t, uint64_t, int*, float*);
void pdf_annot_interior_color(uint64_t, uint64_t, int*, float*);
void pdf_append_token(uint64_t, uint64_t, int32_t, uint64_t);
void pdf_arena_free_obj(uint64_t, uint64_t);
void pdf_array_delete(uint64_t, uint64_t, int32_t);
void pdf_array_insert(uint64_t, uint64_t, int32_t, uint64_t);
void pdf_array_push(uint64_t, uint64_t, uint64_t);
void pdf_array_push_bool(uint64_t, uint64_t, int32_t);
void pdf_array_push_int(uint64_t, uint64_t, int64_t);
void pdf_array_push_name(uint64_t, uint64_t, uint64_t);
void pdf_array_push_real(uint64_t, uint64_t, double);
void pdf_array_push_string(uint64_t, uint64_t, uint64_t, size_t);
void pdf_array_put(uint64_t, uint64_t, int32_t, uint64_t);
void pdf_clean_file(uint64_t, const char*, const char*, const char*, const void*, int32_t, const const char*);
void pdf_clean_free_string(uint64_t, char*);
void pdf_clean_obj(uint64_t, uint64_t);
void pdf_clean_object_entries(uint64_t, uint64_t);
void pdf_clear_all_signatures(uint64_t, uint64_t);
void pdf_clear_object_arena(uint64_t, uint32_t);
void pdf_clear_pending_events(uint64_t, uint64_t);
void pdf_clear_redact_regions(uint64_t, uint64_t);
void pdf_clear_signature(uint64_t, uint64_t);
void pdf_clear_xref_marks(uint64_t, uint64_t);
void pdf_clip_page(uint64_t, uint64_t, void*);
void pdf_close_processor(uint64_t, uint64_t);
void pdf_cmap_free_string(uint64_t, char*);
void pdf_cmyk_to_rgb(float, float, float, float, float*, float*, float*);
void pdf_compact_object_arena(uint64_t, uint32_t);
void pdf_compress_streams(uint64_t, uint64_t, int32_t);
void pdf_convert_color(uint64_t, uint64_t, const float*, int32_t, uint64_t, float*, int32_t);
void pdf_count_q_balance(uint64_t, uint64_t, uint64_t, uint64_t, int*, int*);
void pdf_create_object_streams(uint64_t, uint64_t);
void pdf_decompress_streams(uint64_t, uint64_t);
void pdf_deduplicate_objects(uint64_t, uint64_t);
void pdf_delete_annot(uint64_t, uint64_t, uint64_t);
void pdf_delete_object(uint64_t, uint64_t, int32_t);
void pdf_deselect_layer_config_ui(uint64_t, uint64_t, int32_t);
void pdf_dict_dels(uint64_t, uint64_t, const char*);
void pdf_dict_put(uint64_t, uint64_t, uint64_t, uint64_t);
void pdf_dict_put_bool(uint64_t, uint64_t, uint64_t, int32_t);
void pdf_dict_put_int(uint64_t, uint64_t, uint64_t, int64_t);
void pdf_dict_put_name(uint64_t, uint64_t, uint64_t, const char*);
void pdf_dict_put_real(uint64_t, uint64_t, uint64_t, double);
void pdf_dict_put_string(uint64_t, uint64_t, uint64_t, const char*, size_t);
void pdf_dict_puts(uint64_t, uint64_t, const char*, uint64_t);
void pdf_dirty_obj(uint64_t, uint64_t);
void pdf_disable_js(uint64_t, uint64_t);
void pdf_drop_3d_annotation(uint64_t, uint64_t);
void pdf_drop_alert_event(void*);
void pdf_drop_annot(uint64_t, uint64_t);
void pdf_drop_cmap(uint64_t, uint64_t);
void pdf_drop_event_handler(uint64_t, uint64_t);
void pdf_drop_font(uint64_t, uint64_t);
void pdf_drop_form(uint64_t, uint64_t);
void pdf_drop_function(uint64_t, uint64_t);
void pdf_drop_image_rewriter_options(void*);
void pdf_drop_js(uint64_t, uint64_t);
void pdf_drop_mail_doc_event(void*);
void pdf_drop_obj(uint64_t, uint64_t);
void pdf_drop_object_arena(uint64_t, uint32_t);
void pdf_drop_ocg(uint64_t, uint64_t);
void pdf_drop_page(uint64_t, uint64_t);
void pdf_drop_page_tree(uint64_t, uint64_t);
void pdf_drop_page_tree_internal(uint64_t, uint64_t);
void pdf_drop_pattern(uint64_t, uint64_t);
void pdf_drop_portfolio(uint64_t, uint64_t);
void pdf_drop_processor(uint64_t, uint64_t);
void pdf_drop_redact_context(uint64_t, uint64_t);
void pdf_drop_resource_stack(uint64_t, uint64_t);
void pdf_drop_resource_tables(uint64_t, uint64_t);
void pdf_drop_shade_recolor_context(uint64_t, uint64_t);
void pdf_drop_signature_info(uint64_t, uint64_t);
void pdf_drop_signer(uint64_t, uint64_t);
void pdf_drop_verifier(uint64_t, uint64_t);
void pdf_drop_xref(uint64_t, uint64_t);
void pdf_drop_zugferd_context(uint64_t, uint64_t);
void pdf_empty_store(uint64_t, uint64_t);
void pdf_enable_js(uint64_t, uint64_t);
void pdf_enable_layer(uint64_t, uint64_t, int32_t, int32_t);
void pdf_end_hmtx(uint64_t, uint64_t);
void pdf_end_vmtx(uint64_t, uint64_t);
void pdf_eval_function(uint64_t, uint64_t, const float*, int32_t, float*, int32_t);
void pdf_event_issue_alert(uint64_t, uint64_t, const void*);
void pdf_event_issue_exec_menu_item(uint64_t, uint64_t, const char*);
void pdf_event_issue_launch_url(uint64_t, uint64_t, const char*, int32_t);
void pdf_event_issue_mail_doc(uint64_t, uint64_t, const void*);
void pdf_event_issue_print(uint64_t, uint64_t);
void pdf_field_bg_color(uint64_t, uint64_t, float*);
void pdf_field_border_color(uint64_t, uint64_t, float*);
void pdf_field_clear_selection(uint64_t, uint64_t);
void pdf_filter_annot_contents(uint64_t, uint64_t, uint64_t, void*);
void pdf_filter_page_contents(uint64_t, uint64_t, uint64_t, void*);
void pdf_flatten_inheritable_page_items(uint64_t, uint64_t);
void pdf_font_free_string(uint64_t, char*);
void pdf_free_layer_config_ui_text(void*);
void pdf_free_name_string(char*);
void pdf_garbage_collect(uint64_t, uint64_t, int32_t);
void pdf_gray_to_rgb(float, float*, float*, float*);
void pdf_js_clear_console_log(uint64_t);
void pdf_js_clear_last_error(uint64_t);
void pdf_js_event_init(uint64_t, uint64_t, const char*, int32_t);
void pdf_js_event_init_keystroke(uint64_t, uint64_t, void*);
void pdf_js_event_set_rc(uint64_t, int32_t);
void pdf_js_event_set_value(uint64_t, const char*);
void pdf_js_execute(uint64_t, const char*, const char*, char*);
void pdf_js_free_string(uint64_t, char*);
void pdf_js_register_script(uint64_t, const char*, const char*);
void pdf_js_run_script(uint64_t, const char*, char*);
void pdf_js_set_global(uint64_t, const char*, const char*);
void pdf_layer_config_info(uint64_t, uint64_t, int32_t, void*);
void pdf_layer_config_ui_info(uint64_t, uint64_t, int32_t, void*);
void pdf_layer_free_string(uint64_t, char*);
void pdf_lexbuf_fin(uint64_t, uint64_t);
void pdf_lexbuf_free_string(uint64_t, char*);
void pdf_linearize(uint64_t, uint64_t, const char*);
void pdf_load_encoding(const char*, const char*);
void pdf_load_page_tree(uint64_t, uint64_t);
void pdf_load_type3_glyphs(uint64_t, uint64_t, uint64_t);
void pdf_mail_doc_set_subject(void*, const char*);
void pdf_mail_doc_set_to(void*, const char*);
void pdf_map_one_to_many(uint64_t, uint64_t, uint32_t, const int*, size_t);
void pdf_map_range_to_range(uint64_t, uint64_t, uint32_t, uint32_t, int32_t);
void pdf_nuke_annots(uint64_t, uint64_t);
void pdf_nuke_links(uint64_t, uint64_t);
void pdf_nuke_page(uint64_t, uint64_t);
void pdf_op_B(uint64_t, uint64_t);
void pdf_op_BDC(uint64_t, uint64_t, const char*);
void pdf_op_BI(uint64_t, uint64_t, uint64_t);
void pdf_op_BMC(uint64_t, uint64_t, const char*);
void pdf_op_BT(uint64_t, uint64_t);
void pdf_op_BX(uint64_t, uint64_t);
void pdf_op_Bstar(uint64_t, uint64_t);
void pdf_op_CS(uint64_t, uint64_t, const char*);
void pdf_op_DP(uint64_t, uint64_t, const char*);
void pdf_op_Do_form(uint64_t, uint64_t, const char*, uint64_t);
void pdf_op_Do_image(uint64_t, uint64_t, const char*, uint64_t);
void pdf_op_EMC(uint64_t, uint64_t);
void pdf_op_END(uint64_t, uint64_t);
void pdf_op_EOD(uint64_t, uint64_t);
void pdf_op_ET(uint64_t, uint64_t);
void pdf_op_EX(uint64_t, uint64_t);
void pdf_op_F(uint64_t, uint64_t);
void pdf_op_G(uint64_t, uint64_t, float);
void pdf_op_J(uint64_t, uint64_t, int32_t);
void pdf_op_K(uint64_t, uint64_t, float, float, float, float);
void pdf_op_M(uint64_t, uint64_t, float);
void pdf_op_MP(uint64_t, uint64_t, const char*);
void pdf_op_Q(uint64_t, uint64_t);
void pdf_op_RG(uint64_t, uint64_t, float, float, float);
void pdf_op_S(uint64_t, uint64_t);
void pdf_op_SC_color(uint64_t, uint64_t, int32_t, const float*);
void pdf_op_TD(uint64_t, uint64_t, float, float);
void pdf_op_TJ(uint64_t, uint64_t);
void pdf_op_TL(uint64_t, uint64_t, float);
void pdf_op_Tc(uint64_t, uint64_t, float);
void pdf_op_Td(uint64_t, uint64_t, float, float);
void pdf_op_Tf(uint64_t, uint64_t, const char*, float);
void pdf_op_Tj(uint64_t, uint64_t, const char*, size_t);
void pdf_op_Tm(uint64_t, uint64_t, float, float, float, float, float, float);
void pdf_op_Tr(uint64_t, uint64_t, int32_t);
void pdf_op_Ts(uint64_t, uint64_t, float);
void pdf_op_Tstar(uint64_t, uint64_t);
void pdf_op_Tw(uint64_t, uint64_t, float);
void pdf_op_Tz(uint64_t, uint64_t, float);
void pdf_op_W(uint64_t, uint64_t);
void pdf_op_Wstar(uint64_t, uint64_t);
void pdf_op_b(uint64_t, uint64_t);
void pdf_op_bstar(uint64_t, uint64_t);
void pdf_op_c(uint64_t, uint64_t, float, float, float, float, float, float);
void pdf_op_cm(uint64_t, uint64_t, float, float, float, float, float, float);
void pdf_op_cs(uint64_t, uint64_t, const char*);
void pdf_op_d(uint64_t, uint64_t, const float*, int32_t, float);
void pdf_op_d0(uint64_t, uint64_t, float, float);
void pdf_op_d1(uint64_t, uint64_t, float, float, float, float, float, float);
void pdf_op_dquote(uint64_t, uint64_t, float, float, const char*, size_t);
void pdf_op_f(uint64_t, uint64_t);
void pdf_op_fstar(uint64_t, uint64_t);
void pdf_op_g(uint64_t, uint64_t, float);
void pdf_op_gs_BM(uint64_t, uint64_t, const char*);
void pdf_op_gs_CA(uint64_t, uint64_t, float);
void pdf_op_gs_OP(uint64_t, uint64_t, int32_t);
void pdf_op_gs_OPM(uint64_t, uint64_t, int32_t);
void pdf_op_gs_begin(uint64_t, uint64_t, const char*);
void pdf_op_gs_ca(uint64_t, uint64_t, float);
void pdf_op_gs_end(uint64_t, uint64_t);
void pdf_op_gs_op(uint64_t, uint64_t, int32_t);
void pdf_op_h(uint64_t, uint64_t);
void pdf_op_i(uint64_t, uint64_t, float);
void pdf_op_j(uint64_t, uint64_t, int32_t);
void pdf_op_k(uint64_t, uint64_t, float, float, float, float);
void pdf_op_l(uint64_t, uint64_t, float, float);
void pdf_op_m(uint64_t, uint64_t, float, float);
void pdf_op_n(uint64_t, uint64_t);
void pdf_op_q(uint64_t, uint64_t);
void pdf_op_re(uint64_t, uint64_t, float, float, float, float);
void pdf_op_rg(uint64_t, uint64_t, float, float, float);
void pdf_op_ri(uint64_t, uint64_t, const char*);
void pdf_op_s(uint64_t, uint64_t);
void pdf_op_sc_color(uint64_t, uint64_t, int32_t, const float*);
void pdf_op_sh(uint64_t, uint64_t, const char*);
void pdf_op_squote(uint64_t, uint64_t, const char*, size_t);
void pdf_op_v(uint64_t, uint64_t, float, float, float, float);
void pdf_op_w(uint64_t, uint64_t, float);
void pdf_op_y(uint64_t, uint64_t, float, float, float, float);
void pdf_optimize(uint64_t, uint64_t, const char*);
void pdf_page_obj_transform(uint64_t, uint64_t, void*, void*);
void pdf_page_obj_transform_box(uint64_t, uint64_t, void*, void*, int32_t);
void pdf_page_transform(uint64_t, uint64_t, void*, void*);
void pdf_page_transform_box(uint64_t, uint64_t, void*, void*, int32_t);
void pdf_parsed_obj_drop(uint64_t, uint64_t);
void pdf_parser_drop(uint64_t, uint64_t);
void pdf_parser_set_pos(uint64_t, uint64_t, size_t);
void pdf_pkcs7_verifier_add_cert(uint64_t, uint64_t, const unsigned char*, size_t);
void pdf_portfolio_free_string(char*);
void pdf_print_font(uint64_t, uint64_t, uint64_t);
void pdf_process_annot(uint64_t, uint64_t, uint64_t);
void pdf_process_contents(uint64_t, uint64_t, uint64_t, uint64_t, uint64_t, uint64_t);
void pdf_process_glyph(uint64_t, uint64_t, uint64_t, uint64_t);
void pdf_process_raw_contents(uint64_t, uint64_t, uint64_t, uint64_t);
void pdf_processor_get_ctm(uint64_t, uint64_t, float*, float*, float*, float*, float*, float*);
void pdf_processor_push_resources(uint64_t, uint64_t, uint64_t);
void pdf_purge_local_resources(uint64_t, uint64_t);
void pdf_purge_locals_from_store(uint64_t, uint64_t);
void pdf_purge_object_from_store(uint64_t, uint64_t, int32_t);
void pdf_rearrange_pages(uint64_t, uint64_t, int32_t, const int*, uint64_t);
void pdf_recolor_page(uint64_t, uint64_t, int32_t, const void*);
void pdf_release_name(int32_t);
void pdf_remove_attachments(uint64_t, uint64_t);
void pdf_remove_comments(uint64_t, uint64_t);
void pdf_remove_encryption(uint64_t, void*);
void pdf_remove_hidden_content(uint64_t, uint64_t);
void pdf_remove_item(uint64_t, const void*, uint64_t);
void pdf_remove_javascript(uint64_t, uint64_t);
void pdf_remove_metadata_field(uint64_t, uint64_t, uint64_t);
void pdf_remove_object_streams(uint64_t, uint64_t);
void pdf_remove_output_intents(uint64_t, uint64_t);
void pdf_remove_unused_resources(uint64_t, uint64_t);
void pdf_renumber_objects(uint64_t, uint64_t);
void pdf_reset_form(uint64_t, uint64_t);
void pdf_reset_processor(uint64_t, uint64_t);
void pdf_rewrite_images(uint64_t, uint64_t, void*);
void pdf_rgb_to_cmyk(float, float, float, float*, float*, float*, float*);
void pdf_run_page(uint64_t, uint64_t, uint64_t, uint64_t, uint64_t);
void pdf_run_page_annots(uint64_t, uint64_t, uint64_t, uint64_t, uint64_t);
void pdf_run_page_annots_with_usage(uint64_t, uint64_t, uint64_t, uint64_t, const char*, uint64_t);
void pdf_run_page_contents(uint64_t, uint64_t, uint64_t, uint64_t, uint64_t);
void pdf_run_page_contents_with_usage(uint64_t, uint64_t, uint64_t, uint64_t, const char*, uint64_t);
void pdf_run_page_widgets(uint64_t, uint64_t, uint64_t, uint64_t, uint64_t);
void pdf_run_page_widgets_with_usage(uint64_t, uint64_t, uint64_t, uint64_t, const char*, uint64_t);
void pdf_run_page_with_usage(uint64_t, uint64_t, uint64_t, uint64_t, const char*, uint64_t);
void pdf_sample_shade_function(uint64_t, float*, int32_t, int32_t, uint64_t, float, float);
void pdf_sanitize_metadata(uint64_t, uint64_t);
void pdf_save_document(uint64_t, uint64_t, const char*, const void*);
void pdf_save_journal(uint64_t, uint64_t, const char*);
void pdf_save_snapshot(uint64_t, uint64_t, const char*);
void pdf_select_layer_config(uint64_t, uint64_t, int32_t);
void pdf_select_layer_config_ui(uint64_t, uint64_t, int32_t);
void pdf_set_annot_author(uint64_t, uint64_t, uint64_t);
void pdf_set_annot_border_width(uint64_t, uint64_t, float);
void pdf_set_annot_color(uint64_t, uint64_t, int32_t, const float*);
void pdf_set_annot_contents(uint64_t, uint64_t, uint64_t);
void pdf_set_annot_flags(uint64_t, uint64_t, uint32_t);
void pdf_set_annot_interior_color(uint64_t, uint64_t, int32_t, const float*);
void pdf_set_annot_line(uint64_t, uint64_t, fz_point, fz_point);
void pdf_set_annot_opacity(uint64_t, uint64_t, float);
void pdf_set_annot_rect(uint64_t, uint64_t, fz_rect);
void pdf_set_bitonal_recompress(void*, int32_t);
void pdf_set_bitonal_subsample(void*, int32_t, int32_t, int32_t);
void pdf_set_cid_to_gid(uint64_t, uint64_t, const uint16_t*, size_t);
void pdf_set_cid_to_ucs(uint64_t, uint64_t, const uint16_t*, size_t);
void pdf_set_cmap_name(uint64_t, uint64_t, const char*);
void pdf_set_cmap_wmode(uint64_t, uint64_t, int32_t);
void pdf_set_color_jpeg_quality(void*, const char*);
void pdf_set_color_recompress(void*, int32_t);
void pdf_set_color_subsample(void*, int32_t, int32_t, int32_t);
void pdf_set_default_hmtx(uint64_t, uint64_t, int32_t);
void pdf_set_default_vmtx(uint64_t, uint64_t, int32_t, int32_t);
void pdf_set_doc_event_callback(uint64_t, uint64_t, uint64_t, uint64_t, void*);
void pdf_set_encryption(uint64_t, void*, int32_t, int32_t, const char*, const char*);
void pdf_set_field_alignment(uint64_t, uint64_t, int32_t);
void pdf_set_field_bg_color(uint64_t, uint64_t, const float*);
void pdf_set_field_border_color(uint64_t, uint64_t, const float*);
void pdf_set_field_border_width(uint64_t, uint64_t, float);
void pdf_set_field_flags(uint64_t, uint64_t, uint32_t);
void pdf_set_field_font_size(uint64_t, uint64_t, float);
void pdf_set_field_max_len(uint64_t, uint64_t, int32_t);
void pdf_set_font_flags(uint64_t, uint64_t, int32_t);
void pdf_set_font_name(uint64_t, uint64_t, const char*);
void pdf_set_font_wmode(uint64_t, uint64_t, int32_t);
void pdf_set_gray_jpeg_quality(void*, const char*);
void pdf_set_gray_recompress(void*, int32_t);
void pdf_set_gray_subsample(void*, int32_t, int32_t, int32_t);
void pdf_set_layer_config_as_default(uint64_t, uint64_t);
void pdf_set_obj_parent(uint64_t, uint64_t, int32_t);
void pdf_set_page_box(uint64_t, uint64_t, int32_t, uint64_t);
void pdf_set_page_tree_cache(uint64_t, uint64_t, int32_t);
void pdf_set_redact_annot_color(uint64_t, uint64_t, float, float, float);
void pdf_set_redact_annot_text(uint64_t, uint64_t, uint64_t);
void pdf_set_redact_options(uint64_t, uint64_t, uint64_t);
void pdf_set_usecmap(uint64_t, uint64_t, uint64_t);
void pdf_shade_recolor_set_opaque(uint64_t, uint64_t, void*);
void pdf_sign_signature(uint64_t, uint64_t, uint64_t, int64_t, const char*, const char*);
void pdf_signature_drop_distinguished_name(uint64_t, uint64_t);
void pdf_signature_free_string(uint64_t, char*);
void pdf_signature_set_value(uint64_t, uint64_t, uint64_t, uint64_t, int64_t);
void pdf_sort_cmap(uint64_t, uint64_t);
void pdf_store_item(uint64_t, uint64_t, void*, size_t);
void pdf_subset_fonts(uint64_t, uint64_t, int32_t, const int*);
void pdf_sync_annots(uint64_t, uint64_t);
void pdf_sync_links(uint64_t, uint64_t);
void pdf_sync_open_pages(uint64_t, uint64_t);
void pdf_sync_page(uint64_t, uint64_t);
void pdf_toggle_layer_config_ui(uint64_t, uint64_t, int32_t);
void pdf_unmark_obj(uint64_t, uint64_t);
void pdf_update_xobject(uint64_t, uint64_t, uint64_t, const float*, const float*, uint64_t, uint64_t);
void pdf_vectorize_page(uint64_t, uint64_t);
void pdf_vectorize_pages(uint64_t, uint64_t, int32_t, const int*, uint64_t);
void pdf_write_document(uint64_t, uint64_t, uint64_t, const void*);
void pdf_write_journal(uint64_t, uint64_t, uint64_t);
void pdf_write_snapshot(uint64_t, uint64_t, uint64_t);
void pdf_xobject_bbox(uint64_t, uint64_t, float*);
void pdf_xobject_matrix(uint64_t, uint64_t, float*);
void pdf_xref_free_string(char*);
void pdf_zugferd_free_string(char*);
void* pdf_find_item(uint64_t, const void*, uint64_t);
void* pdf_get_doc_event_callback_data(uint64_t, uint64_t);
void* pdf_new_alert_event(void);
void* pdf_new_mail_doc_event(void);
void* pdf_page_presentation(uint64_t, uint64_t, void*, float*);
void* pdf_parse_write_options(uint64_t, void*, const char*);

    // ============================================================================
    // SVG FUNCTIONS (32 functions)
    // ============================================================================

char* svg_element_type_name(uint64_t, int32_t);
char* svg_get_attribute(uint64_t, uint64_t, const char*);
char* svg_get_element_id(uint64_t, uint64_t);
char* svg_path_command_name(uint64_t, int32_t, int32_t);
float svg_get_height(uint64_t, uint64_t);
float svg_get_width(uint64_t, uint64_t);
int32_t svg_add_path_command(uint64_t, uint64_t, int32_t, int32_t, const float*, int32_t);
int32_t svg_get_element_type(uint64_t, uint64_t);
int32_t svg_get_viewbox(uint64_t, uint64_t, float*, float*, float*, float*);
int32_t svg_parse_color(uint64_t, const char*, unsigned char*, unsigned char*, unsigned char*);
int32_t svg_parse_device_options(uint64_t, const char*, int*, int*, int*);
int32_t svg_path_command_count(uint64_t, uint64_t);
int32_t svg_set_attribute(uint64_t, uint64_t, const char*, const char*);
int32_t svg_set_element_id(uint64_t, uint64_t, const char*);
int32_t svg_set_fill(uint64_t, uint64_t, uint8_t, uint8_t, uint8_t, uint8_t);
int32_t svg_set_opacity(uint64_t, uint64_t, float);
int32_t svg_set_size(uint64_t, uint64_t, float, float);
int32_t svg_set_stroke(uint64_t, uint64_t, uint8_t, uint8_t, uint8_t, uint8_t);
int32_t svg_set_stroke_width(uint64_t, uint64_t, float);
int32_t svg_set_transform_matrix(uint64_t, uint64_t, float, float, float, float, float, float);
int32_t svg_set_transform_rotate(uint64_t, uint64_t, float, float, float);
int32_t svg_set_transform_scale(uint64_t, uint64_t, float, float);
int32_t svg_set_transform_translate(uint64_t, uint64_t, float, float);
int32_t svg_set_viewbox(uint64_t, uint64_t, float, float, float, float);
uint64_t svg_new_device(uint64_t, uint64_t, float, float, int32_t, int32_t);
uint64_t svg_new_document(uint64_t);
uint64_t svg_new_element(uint64_t, int32_t);
uint64_t svg_open_document(uint64_t, const char*);
uint64_t svg_open_document_with_stream(uint64_t, uint64_t);
void svg_drop_document(uint64_t, uint64_t);
void svg_drop_element(uint64_t, uint64_t);
void svg_free_string(char*);

    // ============================================================================
    // XPS FUNCTIONS (22 functions)
    // ============================================================================

char* xps_content_type_string(uint64_t, int32_t);
char* xps_get_document_name(uint64_t, uint64_t, int32_t);
char* xps_get_page_name(uint64_t, uint64_t, int32_t);
char* xps_get_part_content_type(uint64_t, uint64_t, const char*);
const unsigned char* xps_get_part_data(uint64_t, uint64_t, const char*, size_t*);
int32_t xps_add_part(uint64_t, uint64_t, const char*, const unsigned char*, size_t, const char*);
int32_t xps_add_target(uint64_t, uint64_t, const char*, int32_t);
int32_t xps_count_documents(uint64_t, uint64_t);
int32_t xps_count_pages(uint64_t, uint64_t);
int32_t xps_count_pages_in_document(uint64_t, uint64_t, int32_t);
int32_t xps_font_count(uint64_t, uint64_t);
int32_t xps_get_page_size(uint64_t, uint64_t, int32_t, float*, float*);
int32_t xps_has_part(uint64_t, uint64_t, const char*);
int32_t xps_lookup_font(uint64_t, uint64_t, const char*);
int32_t xps_lookup_target(uint64_t, uint64_t, const char*);
int32_t xps_resolve_url(uint64_t, const char*, const char*, char*, int32_t);
uint64_t xps_new_document(uint64_t);
uint64_t xps_open_document(uint64_t, const char*);
uint64_t xps_open_document_with_directory(uint64_t, uint64_t);
uint64_t xps_open_document_with_stream(uint64_t, uint64_t);
void xps_drop_document(uint64_t, uint64_t);
void xps_free_string(char*);

"""

__all__ = ["FULL_FFI_DEFS"]
